@@ -7,12 +7,14 @@ import numpy as np
 import os
 import logging
 import matplotlib.pyplot as plt
+import pathlib
 
 # local imports
 import avaframe.com1DFA.DFAtools as DFAtls
 import avaframe.com1DFA.DFAfunctionsCython as DFAfunC
 import avaframe.in2Trans.ascUtils as IOf
 import avaframe.out3Plot.plotUtils as pU
+import avaframe.in3Utils.fileHandlerUtils as fU
 
 
 # create local logger
@@ -46,15 +48,18 @@ def getReleaseThickness(avaDir, cfg, demFile):
 
     relDict = {'relTh': relTh, 'demOri': demOri, 'X': X, 'Y': Y}
 
+    # save release thickness field to file
+    relThPath = pathlib.Path(avaDir, 'Inputs', 'RELTH')
+    fU.makeADir(relThPath)
+    relThFile = relThPath / 'releaseThickness.asc'
+    IOf.writeResultToAsc(demOri['header'], relTh, relThFile, flip=True)
+
     return relDict
 
 
-def postProcessFPcom1DFA(cfgGen, Particles, Fields, ind_t, relDict):
+def postProcessFPcom1DFA(cfgGen, particles, fields, ind_t, relDict):
     """ get fields and particles dictionaries for given time step """
 
-    fields = Fields[ind_t]
-    particles = Particles[ind_t]
-
     demOri = relDict['demOri']
     nrows = demOri['header']['nrows']
     ncols = demOri['header']['ncols']
@@ -70,7 +75,8 @@ def postProcessFPcom1DFA(cfgGen, Particles, Fields, ind_t, relDict):
     m = particles['m']
     h = particles['h']
     force2 = {}
-    particles, force2 = DFAfunC.computeForceSPHC(cfgGen, particles, force2, dem, gradient=1)
+    particles, force2 = DFAfunC.computeForceSPHC(cfgGen, particles, force2, dem,
+        cfgGen.getint('sphOption'), gradient=1)
     gradNorm = DFAtls.norm(force2['forceSPHX'], force2['forceSPHY'], force2['forceSPHZ'])
     x1, y1, z1, = DFAtls.normalize(x+xllc, y+yllc, 0*x)
     uMag = DFAtls.norm(ux, uy, 0)
@@ -93,7 +99,7 @@ def postProcessFPcom1DFA(cfgGen, Particles, Fields, ind_t, relDict):
 
 
 def plotProfilesFPtest(cfg, ind_time, relDict, comSol):
-    """ Plot flow depth and gradient for FlatPlane simulation results
+    """ Plot flow thickness and gradient for FlatPlane simulation results
 
         Parameters
         -----------
@@ -139,21 +145,21 @@ def plotProfilesFPtest(cfg, ind_time, relDict, comSol):
     ax1 = fig.add_subplot(121)
     ax2 = fig.add_subplot(122)
 
-    ax1.plot(np.linspace(xllc, xllc+(ncols-1)*csz, ncols), fields['FD'][100,:], '--b', label='field flow depth')
-    ax1.plot(r, h, color='b', marker='.', linestyle='None', label='particle flow depth')
+    ax1.plot(np.linspace(xllc, xllc+(ncols-1)*csz, ncols), fields['FT'][100,:], '--b', label='field flow thickness')
+    ax1.plot(r, h, color='b', marker='.', linestyle='None', label='particle flow thickness')
 
     # ax2.plot(r, grad, color='b', marker='.', linestyle='None')
     ax2.plot(r, gradNorm, color='k', marker='o', linestyle='None', label='SPH gradient used')
     # ax2.plot(r, v, color='b', marker='.', linestyle='None')
 
     ax1.plot(np.linspace(xllc, xllc+(ncols-1)*csz, ncols), relTh[100, :], '--k')
-    ax1.plot(r, H0-mu*(r-deltaX), '-k', label='initial expected flow depth')
+    ax1.plot(r, H0-mu*(r-deltaX), '-k', label='initial expected flow thickness')
     ax1.set_xlabel('r in [m]')
-    ax1.set_title('flow depth, t=%.2f s' % (Tsave))
+    ax1.set_title('flow thickness, t=%.2f s' % (Tsave))
 
     ax2.plot(r, mu*np.ones(np.shape(r)), '-k', label='friction threashold')
     ax2.set_xlabel('r in [m]')
-    ax2.set_title('Gradient of the flow depth')
+    ax2.set_title('Gradient of the flow thickness')
     ax1.legend()
     ax2.legend()
 
