@@ -5,7 +5,6 @@
 # Load modules
 import logging
 import numpy as np
-import numbers
 
 # Local imports
 import avaframe.in3Utils.geoTrans as geoTrans
@@ -78,12 +77,16 @@ def getNormalMesh(dem, num):
 
         Returns
         -------
-            Nx: 2D numpy array
-                x component of the normal vector field on grid points
-            Ny: 2D numpy array
-                y component of the normal vector field on grid points
-            Nz: 2D numpy array
-                z component of the normal vector field on grid points
+        dem: dict
+            dem dict updated with:
+                Nx: 2D numpy array
+                    x component of the normal vector field on grid points
+                Ny: 2D numpy array
+                    y component of the normal vector field on grid points
+                Nz: 2D numpy array
+                    z component of the normal vector field on grid points
+                outOfDEM: 2D boolean numpy array
+                    True if the cell is out the dem, False otherwise
     """
     # read dem header
     header = dem['header']
@@ -271,297 +274,54 @@ def getNormalMesh(dem, num):
         NzCenter = np.where(np.isnan(Nx), Nz, NzCenter)
         Nz = NzCenter
 
-    return 0.5*Nx, 0.5*Ny, 0.5*Nz
+    # if no normal available, put 0 for Nx and Ny and 1 for Nz
+    dem['Nx'] = np.where(np.isnan(Nx), 0., 0.5*Nx)
+    dem['Ny'] = np.where(np.isnan(Ny), 0., 0.5*Ny)
+    dem['Nz'] = 0.5*Nz
+    # build no data mask (used to find out of dem particles)
+    outOfDEM = np.where(np.isnan(dem['rasterData']), 1, 0).astype(bool).flatten()
+    dem['outOfDEM'] = outOfDEM
+    return dem
 
 
-def getAreaMesh(Nx, Ny, Nz, csz, num):
+def getAreaMesh(dem, num):
     """ Get area of grid cells.
 
         Parameters
         ----------
+        dem dict updated with:
             Nx: 2D numpy array
                 x component of the normal vector field on grid points
             Ny: 2D numpy array
                 y component of the normal vector field on grid points
             Nz: 2D numpy array
                 z component of the normal vector field on grid points
-            csz: float
-                cellsize of the grid
+            header : dict
+                dem header (cellsize)
+        num: int
+            chose between 4, 6 or 8 (using then 4, 6 or 8 triangles) or
+            1 to use the simple cross product method (with the diagonals)
 
         Returns
         -------
-            A: 2D numpy array
-                Area of grid cells
+        dem dict updated with:
+            areaRaster: 2D numpy array
+                real area of grid cells
     """
+    csz = dem['header']['cellsize']
+    Nx = dem['Nx']
+    Ny = dem['Ny']
+    Nz = dem['Nz']
     # see documentation and issue 202
     if num == 1:
         A = norm(Nx, Ny, Nz)
     else:
         _, _, NzNormed = normalize(Nx, Ny, Nz)
         A = csz * csz / NzNormed
-    return A
+    dem['areaRaster'] = A
+    return dem
 
 
-def removePart(particles, mask, nRemove, reasonString=''):
-    """ remove given particles
-
-    Parameters
-    ----------
-    particles : dict
-        particles dictionary
-    mask : 1D numpy array
-        particles to keep
-    nRemove : int
-        number of particles removed
-    reasonString: str
-        reason why removing particles - for log message
-
-    Returns
-    -------
-    particles : dict
-        particles dictionary
-    """
-
-    log.info('removed %s particles %s' % (nRemove, reasonString))
-    nPart = particles['Npart']
-    for key in particles:
-        if key == 'Npart':
-            particles['Npart'] = particles['Npart'] - nRemove
-        elif type(particles[key]).__module__ == np.__name__:
-            if np.size(particles[key]) == nPart:
-                particles[key] = particles[key][mask]
-
-    particles['mTot'] = np.sum(particles['m'])
-    return particles
-
-
-def splitPart(particles):
-    """Split big particles
-
-    Split particles bigger than 1.5 times the massPerPart
-
-    Parameters
-    ----------
-    particles : dict
-        particles dictionary
-
-    Returns
-    -------
-    particles : dict
-        particles dictionary
-
-    """
-    massPerPart = particles['massPerPart']
-    m = particles['m']
-    nSplit = np.round(m/massPerPart)
-    Ind = np.where(nSplit > 1)[0]
-    if np.size(Ind) > 0:
-        # loop on particles to split
-        for ind in Ind:
-            # get old values
-            nPart = particles['Npart']
-            nID = particles['nID']
-            # compute new mass and particles to add
-            mNew = m[ind] / nSplit[ind]
-            nAdd = (nSplit[ind]-1).astype('int')
-            # update total number of particles and number of IDs used so far
-            particles['Npart'] = particles['Npart'] + nAdd
-            particles['nID'] = nID + nAdd
-            log.debug('Spliting particle %s in %s' % (ind, nAdd+1))
-            for key in particles:
-                # update splitted particle mass
-                particles['m'][ind] = mNew
-                # add new particles at the end of the arrays
-                if type(particles[key]).__module__ == np.__name__:
-                    # create unique ID for the new particles
-                    if key == 'ID':
-                        particles['ID'] = np.append(particles['ID'], np.arange(nID, nID + nAdd, 1))
-                    # set the parent properties to new particles due to splitting
-                    elif np.size(particles[key]) == nPart:
-                        particles[key] = np.append(particles[key], particles[key][ind]*np.ones((nAdd)))
-
-    particles['mTot'] = np.sum(particles['m'])
-    return particles
-
-
-def mergeParticleDict(particles1, particles2):
-    """Merge two particles dictionary
-
-    Parameters
-    ----------
-    particles1 : dict
-        first particles dictionary
-    particles2 : dict
-        second particles dictionary
-
-    Returns
-    -------
-    particles : dict
-        merged particles dictionary
-
-    """
-    particles = {}
-    nPart1 = particles1['Npart']
-    # loop on the keys from particles1 dicionary
-    for key in particles1:
-        # deal with specific cases
-        # Npart: just sum them up
-        if key == 'Npart':
-            particles['Npart'] = particles1['Npart'] + particles2['Npart']
-        # massPerPart, should stay unchanged. If ever they are different take
-        # the minimum
-        # ToDo: are we sure we want the minimum?
-        elif key == 'massPerPart':
-            particles['massPerPart'] = min(particles1['massPerPart'], particles2['massPerPart'])
-        # now if the value is a numpy array and this key is also in particles2
-        elif (key in particles2) and (type(particles1[key]).__module__ == np.__name__):
-            # deal with the specific cases:
-            # in the case of ID or 'parentID' we assume that bot particles1 and
-            # particles2 were initialized with an ID and parentID starting at 0
-            # here whene we merge the 2 arrays we make sure to shift the value
-            # of particles2 so that the ID stays a unique identifier and
-            # that the parentID is consistent with this shift.
-            if (key == 'ID') or (key == 'parentID'):
-                particles[key] = np.append(particles1[key], particles2[key] + particles1['nID'])
-            # general case where the key value is an array with as many elements
-            # as particles
-            elif np.size(particles1[key]) == nPart1:
-                particles[key] = np.append(particles1[key], particles2[key])
-            # if the array is of size one, (potential energy, mTot...) we just
-            # sum the 2 values
-            else:
-                particles[key] = particles1[key] + particles2[key]
-        # the key is in both dictionaries, it is not an array but it is a
-        # number (int, double, float) then we sum the 2 values
-        elif (key in particles2) and (isinstance(particles1[key], numbers.Number)):
-            particles[key] = particles1[key] + particles2[key]
-        # finaly, if the key is only in particles1 then we give this value to
-        # the new particles
-        else:
-            particles[key] = particles1[key]
-    return particles
-
-
-def findParticles2Track(particles, center, radius):
-    '''Find particles within a circle arround a given point
-
-    Parameters
-    ----------
-    particles : dict
-        particles dictionary (with the 'parentID' array)
-    center : dict
-        point dictionary:
-            x : x coordinate
-            y : y coordinate
-            z : z coordinate
-    radius : float
-        radius of the circle around point
-
-    Returns
-    -------
-    particles2Track : numpy array
-        array with Parent ID of particles to track
-    track: boolean
-        False if no particles are tracked
-    '''
-    track = True
-    x = particles['x']
-    y = particles['y']
-    z = particles['z']
-    xc = center['x']
-    yc = center['y']
-    zc = center['z']
-    r = norm(x-xc, y-yc, z-zc)
-    index = np.where(r <= radius)
-    particles2Track = particles['parentID'][index]
-    log.info('Tracking %d particles' % len(index[0]))
-    if len(index[0]) < 1:
-        log.warning('Found No particles to track ')
-        track = False
-
-    return particles2Track, track
-
-
-def getTrackedParticles(particlesList, particles2Track):
-    '''Track particles along time given the parentID of the particles to track
-
-    Parameters
-    ----------
-    particlesList : list
-        list of particles dictionaries (with the 'parentID' array)
-    particles2Track : numpy array
-        array with the parentID of the particles to track
-
-    Returns
-    -------
-    particlesList : list
-        list of particles dictionaries updated with the 'trackedParticles'
-        array (in the array, the ones correspond to the particles that
-        are tracked)
-    nPartTracked : int
-        total number of tracked particles
-    '''
-    nPartTracked = np.size(particles2Track)
-    # add trackedParticles array to the particles dictionary for every saved time step
-    for particles in particlesList:
-        # find index of particles to track
-        index = [ind for ind, parent in enumerate(particles['parentID']) if parent in particles2Track]
-        nPartTracked = max(nPartTracked, len(index))
-        trackedParticles = np.zeros(particles['Npart'])
-        trackedParticles[index] = 1
-        particles['trackedParticles'] = trackedParticles
-    return particlesList, nPartTracked
-
-
-def getTrackedParticlesProperties(particlesList, nPartTracked, properties):
-    '''Get the desired properties for the tracked particles
-
-    Parameters
-    ----------
-    particlesList : list
-        list of particles dictionaries (with the 'parentID' array)
-    nPartTracked : int
-        total number of tracked particles
-    properties : list
-        list of strings
-
-    Returns
-    -------
-    trackedPartProp : dict
-        dictionary with 2D numpy arrays corresponding to the time series of the
-        properties for the tracked particles (for example if
-        properties = ['x', 'y'], the dictionary will have the keys 'time',
-        'x' and 'y'. trackedPartProp['x'] will be a 2D numpy array, each line
-        corresponds to the 'x' time series of a tracked particle)
-    '''
-    # buid time series for desired properties of tracked particles
-    nTimeSteps = len(particlesList)
-    trackedPartProp = {}
-    trackedPartProp['time'] = np.zeros(nTimeSteps)
-    newProperties = []
-    # initialize
-    for key in properties:
-        if key in particlesList[0]:
-            trackedPartProp[key] = np.zeros((nTimeSteps, nPartTracked))
-            newProperties.append(key)
-        else:
-            log.warning('%s is not a particle property' % key)
-
-    # extract wanted properties and build the time series
-    trackedPartID = []
-    for particles, nTime in zip(particlesList, range(nTimeSteps)):
-        trackedParticles = particles['trackedParticles']
-        trackedPartProp['time'][nTime] = particles['t']
-        index = np.where(trackedParticles == 1)
-        for ind, id in zip(index[0], particles['ID'][index]):
-            if id not in trackedPartID:
-                trackedPartID.append(id)
-            indCol = trackedPartID.index(id)
-            for key in newProperties:
-                trackedPartProp[key][nTime, indCol] = particles[key][ind]
-
-    return trackedPartProp
-
 ##############################################################################
 # ###################### Vectorial functions #################################
 ##############################################################################
