@@ -20,7 +20,7 @@ cfgFull = cfgUtils.getModuleConfig(com1DFA)
 ########################################################################
 # CHOOSE YOUR SETUP
 ##########################################################################
-# Choose the snow depth you want to use (h function)
+# Choose the snow thickness you want to use (h function)
 
 
 def Hfunction(x, y, z):
@@ -60,7 +60,7 @@ slopeAngley = 30*math.pi/180
 NDX = 5
 # choose the number of particles per DX and DY
 # if you choose 3, you will have 3*3 = 9 particles per grid cell
-NPartPerD = [16]
+nPartPerDList = [16]
 
 # choose if the particles should be randomly distributed.
 # 0 no random part, up to 1, random fluctuation of dx/2 and dy/2
@@ -75,7 +75,7 @@ def definePart(dx, dy, Lx, Ly):
     # define particles
     nx = np.int(Lx/dx)-1
     ny = np.int(Ly/dy)-1
-    Npart = nx*ny
+    nPart = nx*ny
     x = np.linspace(dx, Lx-dx, nx)
     y = np.linspace(dy, Ly-dy, ny)
     xx, yy = np.meshgrid(x, y)
@@ -83,9 +83,9 @@ def definePart(dx, dy, Lx, Ly):
     yy = yy.flatten()
     # Xpart = np.array([50., 54.])
     # Ypart = np.array([51., 53.])
-    # Npart = 2
-    Xpart = xx + (np.random.rand(Npart) - 0.5) * dx * coef
-    Ypart = yy + (np.random.rand(Npart) - 0.5) * dy * coef
+    # nPart = 2
+    Xpart = xx + (np.random.rand(nPart) - 0.5) * dx * coef
+    Ypart = yy + (np.random.rand(nPart) - 0.5) * dy * coef
     # adding z component
     Zpart, sx, sy, area = Sfunction(Xpart, Ypart, Lx, Ly)
     Hpart, _, _, _ = Hfunction(Xpart, Ypart, Zpart)
@@ -93,7 +93,7 @@ def definePart(dx, dy, Lx, Ly):
     # Mpart = np.array([2000., 3000.])
     # create dictionary to store particles properties
     particles = {}
-    particles['Npart'] = Npart
+    particles['nPart'] = nPart
     particles['mTot'] = np.sum(Mpart)
     particles['x'] = Xpart
     particles['y'] = Ypart
@@ -129,24 +129,24 @@ def defineGrid(Lx, Ly, csz):
     fields = {}
     fields['pfv'] = Dummy
     fields['ppr'] = Dummy
-    fields['pfd'] = Dummy
+    fields['pft'] = Dummy
     fields['V'] = Dummy
     fields['P'] = Dummy
-    fields['FD'] = Dummy
+    fields['FT'] = Dummy
     return dem, fields
 
 
-def plotFD(ax, x, xx, h, particles, ind, mark, count):
+def plotFT(ax, x, xx, h, particles, ind, mark, count):
     if count == 1:
-        ax.plot(xx, h, color='r', linestyle='-', label='real flow depth')
+        ax.plot(xx, h, color='r', linestyle='-', label='real flow thickness')
     ax.plot(particles[x][ind], particles['h2'][ind], color='b',
-             marker=mark, linestyle='None', label='corrected flow depth N = ' + str(nPartPerD*nPartPerD))
+             marker=mark, linestyle='None', label='corrected flow thickness N = ' + str(nPartPerDList*nPartPerDList))
     ax.plot(particles[x][ind], particles['h1'][ind], color='g',
-             marker=mark, linestyle='None', label='flow depth')
+             marker=mark, linestyle='None', label='flow thickness')
     # ax.plot(particles[x][ind], particles['h2'][ind], color='c',
-    #          marker=mark, linestyle='None', label='half corrected flow depth')
+    #          marker=mark, linestyle='None', label='half corrected flow thickness')
     ax.plot(particles[x][ind], particles['h'][ind], color='k',
-             marker=mark, linestyle='None', label='flow depth bilinear')
+             marker=mark, linestyle='None', label='flow thickness bilinear')
     return ax
 
 
@@ -157,25 +157,25 @@ def plotGrad(ax, x, xx, particles, ind, mark, count):
     #     ax.plot(xx, gz, color='k', linestyle='-', label='real gradHZ')
 
     ax.plot(particles[x][ind], GHX[ind], color='m', marker=mark, markersize=5,
-             linestyle='None', label='SPH N = ' + str(nPartPerD*nPartPerD))
+             linestyle='None', label='SPH N = ' + str(nPartPerDList*nPartPerDList))
     ax.plot(particles[x][ind], GHY[ind], color='m', marker=mark, markersize=5,
              linestyle='None')
     ax.plot(particles[x][ind], GHZ[ind], color='m', marker=mark, markersize=5,
              linestyle='None')
     ax.plot(particles[x][ind], GHX2[ind], color='c', marker=mark, markersize=5,
-             linestyle='None', label='Corrected 1 SPH N = ' + str(nPartPerD*nPartPerD))
+             linestyle='None', label='Corrected 1 SPH N = ' + str(nPartPerDList*nPartPerDList))
     ax.plot(particles[x][ind], GHY2[ind], color='c', marker=mark, markersize=5,
              linestyle='None')
     ax.plot(particles[x][ind], GHZ2[ind], color='c', marker=mark, markersize=5,
              linestyle='None')
     # ax.plot(particles[x][ind], GHX4[ind], color='y', marker=mark, markersize=5,
-    #          linestyle='None', label='Corrected 2 SPH N = ' + str(nPartPerD*nPartPerD))
+    #          linestyle='None', label='Corrected 2 SPH N = ' + str(nPartPerDList*nPartPerDList))
     # ax.plot(particles[x][ind], GHY4[ind], color='y', marker=mark, markersize=5,
     #          linestyle='None')
     # ax.plot(particles[x][ind], GHZ4[ind], color='y', marker=mark, markersize=5,
     #          linestyle='None')
     # ax.plot(particles[x][ind], GHX5[ind], color='b', marker=mark, markersize=5,
-    #          linestyle='None', label='Corrected 3 SPH N = ' + str(nPartPerD*nPartPerD))
+    #          linestyle='None', label='Corrected 3 SPH N = ' + str(nPartPerDList*nPartPerDList))
     # ax.plot(particles[x][ind], GHY5[ind], color='b', marker=mark, markersize=5,
     #          linestyle='None')
     # ax.plot(particles[x][ind], GHZ5[ind], color='b', marker=mark, markersize=5,
@@ -214,7 +214,7 @@ nCells = 30
 Lx = nCells*csz
 Ly = nCells*csz
 
-for nPartPerD in NPartPerD:
+for nPartPerD in nPartPerDList:
     dx = csz/nPartPerD
     dy = csz/nPartPerD
 
@@ -258,8 +258,8 @@ for nPartPerD in NPartPerD:
     indY = particles['indY'].astype('int')
 
     startTime = time.time()
-    # Compute sph FD
-    H, C, W = DFAfunC.computeFDC(cfg, particles, header, Nx, Ny, Nz, indX, indY)
+    # Compute sph FT
+    H, C, W = DFAfunC.computeFTC(cfg, particles, header, Nx, Ny, Nz, indX, indY)
     H = np.asarray(H)
     W = np.asarray(W)
     C = np.asarray(C)
@@ -269,7 +269,7 @@ for nPartPerD in NPartPerD:
     particles['h2'] = H/W
     particles['h3'] = (H-C)/W
     tottime = time.time() - startTime
-    print('Time FD: ', tottime)
+    print('Time FT: ', tottime)
 
     startTime = time.time()
     GHX, GHY, GHZ = DFAfunC.computeGradC(cfg, particles, header, Nx, Ny, Nz, indX, indY, SPHOption=1, gradient=0)
@@ -325,7 +325,7 @@ for nPartPerD in NPartPerD:
     yy = Ly/4*np.ones(100)
     zz = np.zeros(100)
     h, gx, gy, gz = Hfunction(xx, yy, zz)
-    ax1 = plotFD(ax1, 'x', xx, h, particles, ind, mark, count)
+    ax1 = plotFT(ax1, 'x', xx, h, particles, ind, mark, count)
     ax3 = plotGrad(ax3, 'x', xx, particles, ind, mark, count)
 
     ind = np.where(((x > Lx/4-0.5*dx) & (x < Lx/4+0.5*dx)))
@@ -333,7 +333,7 @@ for nPartPerD in NPartPerD:
     xx = Lx/4*np.ones(100)
     zz = np.zeros(100)
     h, gx, gy, gz = Hfunction(xx, yy, zz)
-    ax2 = plotFD(ax2, 'y', yy, h, particles, ind, mark, count)
+    ax2 = plotFT(ax2, 'y', yy, h, particles, ind, mark, count)
     ax4 = plotGrad(ax4, 'y', yy, particles, ind, mark, count)
 
 fig1.legend()
@@ -342,8 +342,8 @@ fig3.legend()
 fig4.legend()
 # Save figure to file
 saveName = '_exact_semirand'
-fig1.savefig(('FD_x' + saveName))
-fig2.savefig(('FD_y' + saveName))
+fig1.savefig(('FT_x' + saveName))
+fig2.savefig(('FT_y' + saveName))
 fig3.savefig(('Grad_x' + saveName))
 fig4.savefig(('Grad_y' + saveName))
 plt.show()
