@@ -194,10 +194,10 @@ def com1DFAOrigMain(cfg, avaDir):
     log.debug('Your current avalanche name: %s' % avaDir)
 
     # Create output and work directories
-    workDir, outDir = iD.initialiseRunDirs(avaDir, modName)
+    workDir, outDir = iD.initialiseRunDirs(avaDir, modName, True)
 
     # Load input data
-    dem, rels, ent, res, entResInfo = gI.getInputData(avaDir, cfgGen, flagDev=False)
+    dem, rels, ent, res, entResInfo = gI.getInputData(avaDir, cfgGen)
 
     # Parameter variation
     if cfgPar.getboolean('parameterVar'):
@@ -226,7 +226,7 @@ def com1DFAOrigMain(cfg, avaDir):
         resistanceArea = ''
         if 'ent' in simTypeList:
             entrainmentArea = os.path.splitext(os.path.basename(ent))[0]
-            if cfg['ENTRAINMENT'].getboolean('setEntDepth'):
+            if cfg['ENTRAINMENT'].getboolean('setEntThickness'):
                 entrainmentTH = cfg['ENTRAINMENT']['entH']
                 log.info('Entrainment thickness is changed! set to %s' % entrainmentTH)
         if 'res' in simTypeList:
