@@ -5,7 +5,6 @@
 
 import pathlib
 import shapefile
-import sys
 import copy
 import numpy as np
 import logging
@@ -49,6 +48,8 @@ def SHP2Array(infile, defname=None):
             arrays (as many indexes as features)
         thickness (optional) : 1D numpy array
             np array with the (release or entrainment) thickness of each feature (as many values as features)
+        id : list
+            list of oid as string for each feature
 
 
     """
@@ -61,13 +62,10 @@ def SHP2Array(infile, defname=None):
     rho = None
     sks = None
     iso = None
+    id = None
 
     # get coordinate system
-    prjfile = infile.with_suffix('.prj')
-    if prjfile.is_file():
-        prjf = open(prjfile, 'r')
-        sks = prjf.readline()
-        prjf.close()
+    sks = getSHPProjection(infile)
 
     # Start reading the shapefile
     records = sf.shapeRecords()
@@ -77,6 +75,7 @@ def SHP2Array(infile, defname=None):
     SHPdata['sks'] = sks
     Name = []
     thicknessList = []
+    idList = []
     Length = np.empty((0))
     Start = np.empty((0))
     Coordx = np.empty((0))
@@ -128,6 +127,11 @@ def SHP2Array(infile, defname=None):
             Coordy = np.append(Coordy, pt[1])
             Coordz = np.append(Coordz, z)
 
+    # get unique ID of features in shapefile
+    for rec in sf.records():
+        id = rec.oid
+        idList.append(str(id))
+
     SHPdata['Name'] = Name
     SHPdata['thickness'] = thicknessList
     SHPdata['Start'] = Start
@@ -135,12 +139,97 @@ def SHP2Array(infile, defname=None):
     SHPdata['x'] = Coordx
     SHPdata['y'] = Coordy
     SHPdata['z'] = Coordz
+    SHPdata['id'] = idList
 
     sf.close()
 
     return SHPdata
 
 
+def getSHPProjection(infile):
+    """ Fetch projection from shp file
+
+    Parameters
+    ----------
+    infile: str
+        path to shape file
+
+    Returns
+    -------
+    sks: str
+        projection string (if available, None if not)
+    """
+    # get coordinate system
+    prjfile = infile.with_suffix('.prj')
+    if prjfile.is_file():
+        prjf = open(prjfile, 'r')
+        sks = prjf.readline()
+        prjf.close()
+        return sks
+    else:
+        message = ('No projection layer for shp file %s' % infile)
+        log.warning(message)
+        return None
+
+
+def readThickness(infile, defname=None):
+    """ Read shapefile and fetch info on features' ids and thickness values
+
+    Parameters
+    ----------
+    infile: str
+        path to shape file
+    defname: str
+        name to give to the feature in the shape file
+
+    Returns
+    -------
+    thickness: list
+        list of strings with the (release or entrainment) thickness of each feature (as many values as features)
+    id : list
+        list of strings for oid of each feature in shp file
+
+
+    """
+    #  Input shapefile
+    sf = shapefile.Reader(str(infile))
+    infile = pathlib.Path(infile)
+
+    thickness = None
+    id = None
+
+    # Start reading the shapefile
+    records = sf.shapeRecords()
+    shps = sf.shapes()
+
+    thicknessList = []
+    idList = []
+
+    for n, item in enumerate(shps):
+        pts = item.points
+        zs = [0.0] * len(pts)
+
+        # check if records are available and extract
+        if records:
+            # loop through fields
+            for (name, typ, size, deci), value in zip(sf.fields[1:], records[n].record):
+                # get entity name
+                name = name.lower()
+                if (name == 'thickness') or (name == 'd0'):
+                    thickness = value
+
+        thicknessList.append(str(thickness))
+
+    # get unique ID of features in shapefile
+    for rec in sf.records():
+        id = rec.oid
+        idList.append(str(id))
+
+    sf.close()
+
+    return thicknessList, idList
+
+
 def readLine(fname, defname, dem):
     """ Read line from  .shp
     Use SHP2Array to read the shape file.
@@ -290,3 +379,56 @@ def extractFeature(featureIn, nFeature2Extract):
         featureOut['z'] = featureIn['z'][int(start):int(end)]
 
     return featureOut
+
+
+def writeLine2SHPfile(lineDict, lineName, fileName):
+    """ write a line to shapefile
+
+    Parameters
+    ----------
+    lineDict: dict
+        line dict
+    lineName: str
+        line name
+    fileName: str or pathlib path
+        path where the line will be saved
+    Returns
+    -------
+    fileName : str
+        path where the line has been saved
+    """
+    fileName = str(fileName)
+    line = np.zeros((np.size(lineDict['x']), 2))
+    line[:, 0] = lineDict['x']
+    line[:, 1] = lineDict['y']
+    w = shapefile.Writer(fileName)
+    w.field('name', 'C')
+    w.line([line])
+    w.record(lineName)
+    w.close()
+    return fileName
+
+
+def writePoint2SHPfile(pointDict, pointName, fileName):
+    """ write a point to shapefile
+
+    Parameters
+    ----------
+    pointDict: dict
+        point dict
+    pointName: str
+        point name
+    fileName: str or pathlib path
+        path where the point will be saved
+    Returns
+    -------
+    fileName : str
+        path where the point has been saved
+    """
+    fileName = str(fileName)
+    w = shapefile.Writer(fileName)
+    w.field('name', 'C')
+    w.point(pointDict['x'], pointDict['y'])
+    w.record(pointName)
+    w.close()
+    return fileName
