@@ -4,13 +4,11 @@
 '''
 
 import configparser
-import os
 import logging
 import pathlib
 import hashlib
 import json
 import pandas as pd
-import glob
 import numpy as np
 
 # Local imports
@@ -44,12 +42,12 @@ def getGeneralConfig():
         raise FileNotFoundError('None of the provided cfg files exist ')
 
     # Finally read it
-    cfg,_ = compareConfig(iniFile, 'General', compare)
+    cfg, _ = compareConfig(iniFile, 'General', compare)
 
     return cfg
 
 
-def getModuleConfig(module, fileOverride='', modInfo=False):
+def getModuleConfig(module, fileOverride='', modInfo=False, toPrint=True, onlyDefault=False):
     ''' Returns the configuration for a given module
     returns a configParser object
 
@@ -65,6 +63,8 @@ def getModuleConfig(module, fileOverride='', modInfo=False):
 
     modInfo: bool
         true if dictionary with info on differences to standard config
+    onlyDefault: bool
+        if True, only use the default configuration
 
     Order is as follows:
     fileOverride -> local_MODULECfg.ini -> MODULECfg.ini
@@ -85,14 +85,15 @@ def getModuleConfig(module, fileOverride='', modInfo=False):
 
     # Decide which one to take
     if fileOverride:
-        if os.path.isfile(fileOverride):
+        fileOverride = fU.checkPathlib(fileOverride)
+        if fileOverride.is_file():
             iniFile = [defaultFile, fileOverride]
             compare = True
         else:
             raise FileNotFoundError('Provided fileOverride does not exist: ' +
-                                    fileOverride)
+                                    str(fileOverride))
 
-    elif localFile.is_file():
+    elif localFile.is_file() and not onlyDefault:
         iniFile = localFile
         iniFile = [defaultFile, localFile]
         compare = True
@@ -103,7 +104,7 @@ def getModuleConfig(module, fileOverride='', modInfo=False):
         raise FileNotFoundError('None of the provided cfg files exist ')
 
     # Finally read it
-    cfg, modDict = compareConfig(iniFile, modName, compare, modInfo)
+    cfg, modDict = compareConfig(iniFile, modName, compare, modInfo, toPrint)
 
     if modInfo:
         return cfg, modDict
@@ -136,7 +137,7 @@ def getDefaultModuleConfig(module, toPrint=True):
     log.debug('defaultFile: %s', defaultFile)
 
     # Finally read it
-    cfg,_ = compareConfig(defaultFile, modName, compare=False, toPrint=toPrint)
+    cfg, _ = compareConfig(defaultFile, modName, compare=False, toPrint=toPrint)
 
     return cfg
 
@@ -203,7 +204,20 @@ def compareConfig(iniFile, modName, compare, modInfo=False, toPrint=True):
         for section in locCfg.sections():
             if defCfg.has_section(section):
                 for key in locCfg.items(section):
-                    log.warning('Additional Key [\'%s\'] in section [\'%s\'] is ignored.' % (key[0], section))
+                    # an exception is made for thickness values that are added for the features of a releaseScenario,
+                    # entrainment Scenario or secondar. release scenario
+                    # these are added to the configuration and also to the modDict if variation is applied
+                    validItems = ['entrainmentScenario', 'DEM', 'secondaryReleaseScenario']
+                    searchItems = ['relTh', 'entTh', 'secondaryRelTh']
+                    if any(s in key[0] for s in searchItems) or key[0] in validItems:
+                        locValue = locCfg.get(section, key[0])
+                        cfg.set(section, key[0], locValue)
+                        log.debug('\t\t%s : %s added to %s' % (key[0], locValue, section))
+                        if '$' in locValue:
+                            modString = [locValue, locValue.split('$')[0]]
+                            modDict[section][key[0]] = modString
+                    else:
+                        log.warning('Additional Key [\'%s\'] in section [\'%s\'] is ignored.' % (key[0], section))
             else:
                 cfg.add_section(section)
                 log.info('Additional section [\'%s\'] is added to the configuration.' % (section))
@@ -244,22 +258,22 @@ def writeCfgFile(avaDir, module, cfg, fileName=''):
     """
 
     # get filename of module
-    name = os.path.basename(module.__file__)
+    name = pathlib.Path(module.__file__).name
     modName = name.split('.')[0]
 
     # write to file
     if fileName != '':
         # set outputs
-        outDir = os.path.join(avaDir, 'Outputs', modName, 'configurationFiles')
+        outDir = pathlib.Path(avaDir, 'Outputs', modName, 'configurationFiles')
         fU.makeADir(outDir)
         cfg.optionxform = str
-        with open(os.path.join(outDir, '%s.ini' % (fileName)), 'w') as conf:
+        with open(pathlib.Path(outDir, '%s.ini' % (fileName)), 'w') as conf:
             cfg.write(conf)
     else:
         # set outputs
-        outDir = os.path.join(avaDir, 'Outputs')
+        outDir = pathlib.Path(avaDir, 'Outputs')
         cfg.optionxform = str
-        with open(os.path.join(outDir, '%s_settings.ini' % (modName)), 'w') as conf:
+        with open(pathlib.Path(outDir, '%s_settings.ini' % (modName)), 'w') as conf:
             cfg.write(conf)
 
 
@@ -288,10 +302,10 @@ def readCfgFile(avaDir, module='', fileName=''):
         inFile = fileName
     elif module != '':
         # get module name
-        name = os.path.basename(module.__file__)
+        name = pathlib.Path(module.__file__).name
         modName = name.split('.')[0]
         # set input file
-        inFile = os.path.join(avaDir, 'Outputs', '%s_settings.ini' % (modName))
+        inFile = pathlib.Path(avaDir, 'Outputs', '%s_settings.ini' % (modName))
     else:
         log.error('Please provide either a module or a fileName to read configuration from file')
         raise NameError
@@ -370,7 +384,7 @@ def writeDictToJson(inDict, outFilePath):
     f.close()
 
 
-def createConfigurationInfo(avaDir, standardCfg='', writeCSV=False, specDir=''):
+def createConfigurationInfo(avaDir, comModule='com1DFA', standardCfg='', writeCSV=False, specDir=''):
     """ Read configurations from all simulations configuration ini files from directory
 
         Parameters
@@ -392,12 +406,12 @@ def createConfigurationInfo(avaDir, standardCfg='', writeCSV=False, specDir=''):
 
     # collect all configuration files for this module from directory
     if specDir != '':
-        inDir = os.path.join(specDir, 'configurationFiles')
+        inDir = pathlib.Path(specDir, 'configurationFiles')
     else:
-        inDir = os.path.join(avaDir, 'Outputs', 'com1DFA', 'configurationFiles')
-    configFiles = glob.glob(inDir+os.sep+'*.ini')
+        inDir = pathlib.Path(avaDir, 'Outputs', comModule, 'configurationFiles')
+    configFiles = inDir.glob('*.ini')
 
-    if not os.path.isdir(inDir):
+    if not inDir.is_dir():
         message = 'configuration file directory not found: %s' % (inDir)
         log.error(message)
         raise NotADirectoryError(message)
@@ -408,129 +422,186 @@ def createConfigurationInfo(avaDir, standardCfg='', writeCSV=False, specDir=''):
 
     # create confiparser object, convert to json object, write to dataFrame
     # append all dataFrames
-    count = 0
+    simDF = ''
     for cFile in configFiles:
-        if 'sourceConfiguration' not in cFile:
-            simName = os.path.splitext(os.path.basename(cFile))[0]
+        if 'sourceConfiguration' not in str(cFile):
+            simName = pathlib.Path(cFile).stem
             if '_AF_' in simName:
                 nameParts = simName.split('_AF_')
-                fNamePart = nameParts[0] + '_AF'
                 infoParts = nameParts[1].split('_')
 
             else:
                 nameParts = simName.split('_')
-                fNamePart = nameParts[0]
                 infoParts = nameParts[1:]
-            simHash = infoParts[2]
+            simHash = infoParts[0]
             cfgObject = readCfgFile(avaDir, fileName=cFile)
-            indexItem = [simHash]
-            cfgDict = convertConfigParserToDict(cfgObject)
-            simItemDF = pd.DataFrame(data=cfgDict['GENERAL'], index=indexItem)
-            simItemDF = simItemDF.assign(simName=simName)
-            if count == 0:
-                simDF = simItemDF
-            else:
-                simDF = pd.concat([simDF, simItemDF], axis=0)
-            count = count + 1
+            simDF = appendCgf2DF(simHash, simName, cfgObject, simDF)
 
     # convert numeric parameters to numerics
-    for name, values in simDF.iteritems():
-        simDFTest = simDF[name].str.replace('.', '', regex=True)
-        if simDFTest.str.isdigit()[0]:
-            simDF[name] = pd.to_numeric(simDF[name])
-            log.debug('Converted to numeric %s' % name)
-        else:
-            log.debug('Not converted to numeric: %s' % name)
+    simDF = convertDF2numerics(simDF)
 
     # add default configuration
     if standardCfg != '':
         # read default configuration of this module
-        standardCfgDict = convertConfigParserToDict(standardCfg)
-        simDFCS = pd.DataFrame(data=standardCfgDict['GENERAL'], index=['current standard'])
-        simDF = pd.concat([simDF, simDFCS], axis=0)
+        simDF = appendCgf2DF('current standard', 'current standard', standardCfg, simDF)
 
     # if writeCSV, write dataFrame to csv file
     if writeCSV:
-        outFile = os.path.join(inDir, 'allConfigurations.csv')
-        simDF.to_csv(outFile)
+        writeAllConfigurationInfo(avaDir, simDF, specDir=specDir)
 
     return simDF
 
 
-def filterSims(avalancheDir, parametersDict, specDir=''):
-    """ Filter simulations using a list of parameters and a pandas dataFrame of simulation configurations
+def appendCgf2DF(simHash, simName, cfgObject, simDF):
+    """ append simulation configuration to the simulation dataframe
+        only account for sections GENERAL and INPUT
 
         Parameters
         -----------
-        avalancheDir: str
+        simHash: str
+            hash of the simulation to append
+        simName: str
+            name of the simulation
+        cfgObject: configParser
+            configuration coresponding to the simulation
+        simDF: pandas dataFrame
+            configuration dataframe
+
+        Returns
+        --------
+        simDF: pandas DataFrame
+            DFappended with the new simulation configuration
+    """
+    indexItem = [simHash]
+    cfgDict = convertConfigParserToDict(cfgObject)
+    simItemDFGeneral = pd.DataFrame(data=cfgDict['GENERAL'], index=indexItem)
+    simItemDFInput = pd.DataFrame(data=cfgDict['INPUT'], index=indexItem)
+    simItemDF = pd.concat([simItemDFGeneral, simItemDFInput], axis=1)
+    simItemDF = simItemDF.assign(simName=simName)
+    if isinstance(simDF, str):
+        simDF = simItemDF
+    else:
+        simDF = pd.concat([simDF, simItemDF], axis=0)
+    return simDF
+
+
+def appendTcpu2DF(simHash, tCPU, tCPUDF):
+    """ append Tcpu dictionary to the dataframe
+
+        Parameters
+        -----------
+        simHash: str
+            hash of the simulation corresponding to the tCPU dict to append
+        tCPU: dict
+            cpu time dict of the simulation
+        tCPUDF: pandas dataFrame
+            tCPU dataframe
+
+        Returns
+        --------
+        simDF: pandas DataFrame
+            DFappended with the new simulation configuration
+    """
+    indexItem = [simHash]
+    tCPUItemDF = pd.DataFrame(data=tCPU, index=indexItem)
+    if isinstance(tCPUDF, str):
+        tCPUDF = tCPUItemDF
+    else:
+        tCPUDF = pd.concat([tCPUDF, tCPUItemDF], axis=0)
+    return tCPUDF
+
+
+def convertDF2numerics(simDF):
+    """ convert a string DF to a numerical one
+
+        Parameters
+        -----------
+        simDF: pandas dataFrame
+            dataframe
+
+        Returns
+        --------
+        simDF: pandas DataFrame
+    """
+
+    for name, values in simDF.iteritems():
+        simDFTest = simDF[name].str.replace('.', '', regex=True)
+        # allow for - sign too
+        simDFTest = simDFTest.replace('-', '', regex=True)
+        # also include columns where nan is in first row - so check for any row
+        if simDFTest.str.isdigit().any():
+            # problem here is that it finds even if not present in | although not in ini
+            simDFTest = simDF[name].str.replace('|', '§', regex=True)
+            if simDFTest.str.contains('§').any() == False:
+                simDF[name] = pd.to_numeric(simDF[name])
+                log.debug('Converted to numeric %s' % name)
+        else:
+            log.debug('Not converted to numeric: %s' % name)
+
+    return simDF
+
+
+def readAllConfigurationInfo(avaDir, specDir=''):
+    """ Read allConfigurations.csv file as dataFrame from directory
+
+        Parameters
+        -----------
+        avaDir: str
             path to avalanche directory
-        parametersDict: dict
-            dictionary with parameter and parameter values for filtering
         specDir: str
             path to a directory where simulation configuration files can be found - optional
 
         Returns
         --------
-        simNameList: list
-            list of simNames that match filtering criteria
+        simDF: pandas DataFrame
+            DF with all the simulation configurations
+        simDFName: array
+            simName column of the dataframe
     """
 
-    # load dataFrame for all configurations
-    simDF = createConfigurationInfo(avalancheDir, standardCfg='', writeCSV=False, specDir=specDir)
+    # collect all configuration files for this module from directory
+    if specDir != '':
+        inDir = pathlib.Path(specDir, 'configurationFiles')
+    else:
+        inDir = pathlib.Path(avaDir, 'Outputs', 'com1DFA', 'configurationFiles')
+    configFiles = inDir / 'allConfigurations.csv'
 
-    # filter simulations all conditions in the parametersDict have to be met
-    if parametersDict != '':
-        for key, value in parametersDict.items():
-            if not isinstance(value, (list, np.ndarray)):
-                value = [value]
-            if value != '' and value != []:
-                simDF = simDF[simDF[key].isin(value)]
+    if configFiles.is_file():
+        with open(configFiles, 'rb') as file:
+            simDF = pd.read_csv(file, index_col=0, keep_default_na=False)
+        simDFName = simDF['simName'].to_numpy()
+    else:
+        simDF = None
+        simDFName = []
 
-    # list of simNames after filtering
-    simNameList = simDF['simName'].tolist()
-
-    return simNameList
+    return simDF, simDFName
 
 
-def orderSimFiles(avalancheDir, inputDir, varParList, ascendingOrder, specDir=''):
-    """ Filter simulations results using a list of parameters and a flag if in ascending or descending order
+def writeAllConfigurationInfo(avaDir, simDF, specDir=''):
+    """ Write cfg configuration to allConfigurations.csv
 
         Parameters
         -----------
-        avalancheDir: str
+        avaDir: str
             path to avalanche directory
-        inputDir: str
-            path to simulation results
-        varParList: str or list
-            simulation configuration parameters for ordering simulations
-        ascendingOrder: bool
-            True if simulations shall be ordered in ascending order regarding varPar
+        simDF: pandas dataFrame
+            daaframe of the configuration
         specDir: str
-            path to a directory where simulation configuration files can be found - optional
+            path to a directory where simulation configuration shal be saved - optional
 
         Returns
         --------
-        dataDF: pandas dataFrame
-            dataFrame of simulation results (fileName, ... and values for parameters in varParList)
+        configFiles: pathlib Path
+            path where the configuration dataframe was saved
     """
 
-    # load dataFrame for all configurations
-    simDF = createConfigurationInfo(avalancheDir)
-    # create dataframe for simulation results in inputDir
-    dataDF = fU.makeSimDF(inputDir)
+    # collect all configuration files for this module from directory
+    if specDir != '':
+        inDir = pathlib.Path(specDir, 'configurationFiles')
+    else:
+        inDir = pathlib.Path(avaDir, 'Outputs', 'com1DFA', 'configurationFiles')
+    configFiles = inDir / 'allConfigurations.csv'
 
-    # make sure that parameters used for ordering are provided as list
-    if isinstance(varParList, str):
-        varParList = [varParList]
+    simDF.to_csv(configFiles)
 
-    # append 'simName' for merging of dataframes according to simNames
-    columnNames = ['simName'] + varParList
-
-    # merge varParList parameters as columns to dataDF for matching simNames
-    dataDFNew = dataDF.merge(simDF[columnNames], left_on='simName',
-                             right_on='simName')
-
-    # sort according to varParList and ascendingOrder flag
-    dataDFNew = dataDFNew.sort_values(by=varParList, ascending=ascendingOrder)
-
-    return dataDFNew
+    return configFiles
