@@ -13,7 +13,6 @@ import shutil
 
 # Local imports
 import avaframe.in2Trans.ascUtils as IOf
-from avaframe.in3Utils import cfgUtils
 
 # create local logger
 # change log level in calling module to DEBUG to see log messages
@@ -37,6 +36,26 @@ def makeADir(dirName):
     log.debug('Directory: %s created' % dirName)
 
 
+def checkPathlib(checkPath):
+    """ check if pathlib.PurePath if not convert to
+
+        Parameters
+        ----------
+        checkPath: str or pathlib path
+        path to be checked
+
+        Returns
+        -------
+        checkPath: pathlib path
+            pathlib path version of checkPath
+    """
+
+    if not isinstance(checkPath, pathlib.PurePath):
+        checkPath = pathlib.Path(checkPath)
+
+    return checkPath
+
+
 def readLogFile(logName, cfg=''):
     """ Read experiment log file and make dictionary that contains general info on all simulations
 
@@ -65,7 +84,7 @@ def readLogFile(logName, cfg=''):
         varPar = 'Mu'
 
     # Save info to dictionary, add all result parameters that are saved in com1DFA Outputs
-    logDict = {'noSim' : [], 'simName' : [], varPar: [], 'fullName' : []}
+    logDict = {'noSim': [], 'simName': [], varPar: [], 'fullName': []}
 
     lines = logFile.readlines()[1:]
     countSims = 1
@@ -101,25 +120,13 @@ def extractParameterInfo(avaDir, simName, reportD):
         reportD: dict
             upated report dictionary with info on simulation
         """
-
-    # Get info from ExpLog
-    logName = pathlib.Path(avaDir, 'Outputs', 'com1DFAOrig', 'ExpLog.txt')
-    logDictExp = readLogFile(logName)
-    names = logDictExp['fullName']
-    simNames = sorted(set(names), key=lambda s: s.split("_")[3])
-
     # Initialise parameter dictionary
     parameterDict = {}
 
-    # Initialise fields
-    time = []
-    mass = []
-    entrMass = []
-    stopCrit = ''
-    flagNoStop = True
     # Read log file
     fileName = pathlib.Path(avaDir, 'Outputs', 'com1DFAOrig', 'start%s.log' % (simName))
     logDict = extractLogInfo(fileName)
+    stopCrit = logDict['stopCrit']
 
     # Set values in dictionary
     parameterDict['release mass [kg]'] = logDict['mass'][0]
@@ -134,6 +141,8 @@ def extractParameterInfo(avaDir, simName, reportD):
 
     reportD['Simulation Parameters'].update({'Stop criterion': parameterDict['stop criterion']})
     reportD['Simulation Parameters'].update({'Avalanche run time [s]': parameterDict['final time step [s]']})
+    reportD['Simulation Parameters'].update({'Initial mass [kg]': ('%.2f' % parameterDict['release mass [kg]'])})
+    reportD['Simulation Parameters'].update({'Final mass [kg]': ('%.2f' % parameterDict['current mass [kg]'])})
 
     return parameterDict, reportD
 
@@ -204,7 +213,7 @@ def checkIfFileExists(filePath, fileType=''):
 def checkCommonSims(logName, localLogName):
     """ Check which files are common between local and full ExpLog """
 
-    if os.path.isfile(localLogName) == False:
+    if os.path.isfile(localLogName) is False:
         localLogName = logName
 
     # Read log files and extract info
@@ -256,13 +265,14 @@ def getFilterDict(cfg, section):
     else:
         log.warning('No section %s in configuration file found - cannot create dict for filtering' % section)
 
-
     return parametersDict
 
 
 def splitIniValueToArraySteps(cfgValues, returnList=False):
     """ read values in ini file and return numpy array or list if the items are strings;
         values can either be separated by | or provided in start:end:numberOfSteps format
+        if separated by : or $ also optional add one additional value using &
+        if format of refVal$percent$steps is used - an array is created with +- percent of refVal in nsteps
 
         Parameters
         ----------
@@ -278,10 +288,26 @@ def splitIniValueToArraySteps(cfgValues, returnList=False):
     """
 
     if ':' in cfgValues:
-        itemsInput = cfgValues.split(':')
+        if '&' in cfgValues:
+            itemsInputBig = cfgValues.split('&')
+            itemsInput = itemsInputBig[0].split(':')
+        else:
+            itemsInput = cfgValues.split(':')
         items = np.linspace(float(itemsInput[0]), float(itemsInput[1]), int(itemsInput[2]))
+        if '&' in cfgValues:
+            items = np.append(items, float(itemsInputBig[1]))
     elif cfgValues == '':
         items = []
+    elif '$' in cfgValues:
+        if '&' in cfgValues:
+            itemsPBig = cfgValues.split('&')
+            itemsP = itemsPBig[0].split('$')
+        else:
+            itemsP = cfgValues.split('$')
+        itemsPRange = (float(itemsP[1]) / 100.) * float(itemsP[0])
+        items = np.linspace(float(itemsP[0])-itemsPRange, float(itemsP[0])+itemsPRange, int(itemsP[2]))
+        if '&' in cfgValues:
+            items = np.append(items, float(itemsPBig[1]))
     else:
         itemsL = cfgValues.split('|')
         if returnList:
@@ -304,15 +330,17 @@ def splitIniValueToArraySteps(cfgValues, returnList=False):
     return items
 
 
-def splitTimeValueToArrayInterval(cfgGen):
+def splitTimeValueToArrayInterval(cfgValues, endTime):
     """ read save time step info from ini file and return numpy array of values
 
         values can either be separated by | or provided in start:interval format
 
         Parameters
         ----------
-        cfgGen: configParser object
-            configuration settings, here 'tSteps' used
+        cfgValues: str
+            time steps info
+        endTime: float
+            end time
 
         Returns
         --------
@@ -320,8 +348,6 @@ def splitTimeValueToArrayInterval(cfgGen):
             time step values as 1D numpy array
     """
 
-    cfgValues = cfgGen['tSteps']
-    endTime = cfgGen.getfloat('tEnd')
     if ':' in cfgValues:
         itemsInput = cfgValues.split(':')
         if float(endTime - float(itemsInput[0])) < float(itemsInput[1]):
@@ -346,78 +372,6 @@ def splitTimeValueToArrayInterval(cfgGen):
     return items
 
 
-def getDFADataPaths(avaDir, pathDict, cfg, suffix, comModule='', inputDir=''):
-    """ Determine the paths of the required data from comModule output for Aimec
-
-        Parameters
-        ----------
-        avaDir : str
-            path to avalanche directory
-        pathDict: dict
-            dictionary with paths to simulation results
-        cfg: configParser object
-            configuration for aimec, here 'varPar' and 'ascendingOrder' used
-        suffix : str or list
-            result parameter abbreviation (e.g. 'ppr')
-        comModule : str
-            optional - name of computational module
-        inputDir: str
-            optional - path to a different input directory
-    """
-
-    # Lead all infos on simulations
-    if inputDir == '':
-        inputDir = pathlib.Path(avaDir, 'Outputs', comModule, 'peakFiles')
-        if inputDir.is_dir() == False:
-            message = 'Input directory %s does not exist - check anaMod' % inputDir
-            log.error(message)
-            raise FileNotFoundError(message)
-
-    # check if is string - then convert to list
-    if isinstance(suffix, str):
-        suffix = [suffix]
-
-    # if com1DFA check for configuration files to fetch paramerter values for ordering
-    if comModule == 'com1DFA' and cfg['varParList'] != '':
-
-        # fetch parameters that shall be used for ordering
-        varParList = cfg['varParList'].split('|')
-
-        # create dataFrame with ordered paths to simulation results
-        dataDF = cfgUtils.orderSimFiles(avaDir, inputDir, varParList, cfg['ascendingOrder'])
-
-        for suf in suffix:
-            # get paths for desired resType
-            dataFiles = dataDF[dataDF['resType']==suf]['files'].to_list()
-
-            # add result file paths to pathDict
-            pathDict[suf] = dataFiles
-
-            for pathVal in dataFiles:
-                log.info('Added to pathDict: %s' % (pathVal))
-
-        # add value of first parameter used for ordering for colorcoding in plots
-        pathDict['colorParameter'] = dataDF[dataDF['resType']==suf][varParList[0]].to_list()
-
-    else:
-        # do not apply ordering
-        log.warning('Did not apply ordering')
-        dataDF = makeSimDF(inputDir)
-        for m in range(len(dataDF['files'])):
-            for suf in suffix:
-                if dataDF['resType'][m] == suf:
-                    pathDict[suf].append(dataDF['files'][m])
-                    log.info('Added to pathDict: %s' % (dataDF['files'][m]))
-
-    for suf in suffix:
-        if pathDict[suf] == []:
-            message = 'No files found for %s in directory: %s' % (suf, inputDir)
-            log.error(message)
-            raise FileNotFoundError(message)
-
-    return pathDict
-
-
 def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
     """ Export the simulation results from com1DFA output to desired location
 
@@ -428,7 +382,7 @@ def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
         cfg : dict
             configuration read from ini file that has been used for the com1DFAOrig simulation
         addTSteps : bool
-            if True: first and last time step of flow depth are exported
+            if True: first and last time step of flow thickness are exported
 
     """
 
@@ -456,7 +410,7 @@ def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
     # Path to com1DFA results
     resPath = inputDir / ('FullOutput_%s_' % varPar)
 
-    if addTSteps == True:
+    if addTSteps is True:
         timeStepDir = outDirPF / 'timeSteps'
         makeADir(timeStepDir)
 
@@ -465,13 +419,13 @@ def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
         pathFrom = pathlib.Path('%s%.05f' % (resPath, logDict[varPar][k]),
                                 logDict['simName'][k], 'raster',
                                 '%s_pfd.asc' % logDict['simName'][k])
-        pathTo = outDirPF / ('%s_%.05f_pfd.asc' % (logDict['simName'][k], logDict[varPar][k]))
+        pathTo = outDirPF / ('%s_%.05f_pft.asc' % (logDict['simName'][k], logDict[varPar][k]))
         shutil.copy(pathFrom, pathTo)
-        if addTSteps == True:
+        if addTSteps is True:
             pathFrom = pathlib.Path('%s%.05f' % (resPath, logDict[varPar][k]),
                                     logDict['simName'][k], 'raster',
                                     '%s_fd.asc' % logDict['simName'][k])
-            pathTo = outDirPF / 'timeSteps' / ('%s_%.05f_tLast_fd.asc' % (logDict['simName'][k], logDict[varPar][k]))
+            pathTo = outDirPF / 'timeSteps' / ('%s_%.05f_tLast_ft.asc' % (logDict['simName'][k], logDict[varPar][k]))
             shutil.copy(pathFrom, pathTo)
         pathFrom = pathlib.Path('%s%.05f' % (resPath, logDict[varPar][k]),
                                 logDict['simName'][k], 'raster',
@@ -488,7 +442,7 @@ def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
         pathTo = outDirRep / ('%s_%.05f.html' % (logDict['simName'][k], logDict[varPar][k]))
         shutil.copy(pathFrom, pathTo)
 
-    if addTSteps == True:
+    if addTSteps is True:
 
         # Export peak files and reports
         for k in range(sNo):
@@ -502,6 +456,51 @@ def exportcom1DFAOrigOutput(avaDir, cfg='', addTSteps=False):
     shutil.copy2(pathlib.Path('%s' % inputDir, 'ExpLog.txt'), outDir)
 
 
+def fetchFlowFields(flowFieldsDir, suffix=''):
+    """ fetch paths to all desired flow fields within folder
+
+        Parameters
+        ------------
+        flowFieldsDir: str or pathlib path
+            path to flow field ascii files
+        suffix: str
+            suffix in flow field name to be searched for
+
+        Returns
+        --------
+        flowFields: list
+            list of pathlib paths to flow fields
+
+    """
+
+    # check if pathlib path
+    if isinstance(flowFieldsDir, pathlib.PurePath):
+        flowFieldsDir = pathlib.Path(flowFieldsDir)
+
+    if suffix == '':
+        searchString = '*.asc'
+    else:
+        searchString = '*%s*.asc' % suffix
+    flowFields = list(flowFieldsDir.glob(searchString))
+
+    return flowFields
+
+
+def fileNotFoundMessage(messageName):
+    """ throw error if file not found with message and path
+
+        Parameters
+        -----------
+        messageName: str
+            error message
+
+    """
+
+    log.error(messageName)
+    raise FileNotFoundError(messageName)
+
+
+# ToDo Maybe try to use makeSimFromResDF instead of makeSimDF
 def makeSimDF(inputDir, avaDir='', simID='simID'):
     """ Create a  dataFrame that contains all info on simulations
 
@@ -522,12 +521,12 @@ def makeSimDF(inputDir, avaDir='', simID='simID'):
         -------
         dataDF : dataFrame
             dataframe with full file path, file name, release area scenario, simulation type (null, entres, etc.),
-            model type (dfa, ref, etc.), simID, result type (ppr, pfd, etc.), simulation name,
+            model type (dfa, ref, etc.), simID, result type (ppr, pft, etc.), simulation name,
             cell size and optional name of avalanche, optional time step
     """
 
     # Load input datasets from input directory
-    if isinstance(inputDir, pathlib.Path) == False:
+    if isinstance(inputDir, pathlib.Path) is False:
         inputDir = pathlib.Path(inputDir)
     datafiles = list(inputDir.glob('*.asc'))
 
@@ -536,7 +535,7 @@ def makeSimDF(inputDir, avaDir='', simID='simID'):
 
     # Set name of avalanche if avaDir is given
     # Make dictionary of input data info
-    data = {'files': [], 'names': [], 'resType': [], 'simType': [], 'simName' : [],
+    data = {'files': [], 'names': [], 'resType': [], 'simType': [], 'simName': [],
             'modelType': [], 'releaseArea': [], 'cellSize': [], simID: [], 'timeStep': []}
 
     # Set name of avalanche if avaDir is given
@@ -562,9 +561,9 @@ def makeSimDF(inputDir, avaDir='', simID='simID'):
             infoParts = nameParts[1:]
 
         data['releaseArea'].append(relNameSim)
-        data['simType'].append(infoParts[0])
-        data['modelType'].append(infoParts[1])
-        data[simID].append(infoParts[2])
+        data[simID].append(infoParts[0])
+        data['simType'].append(infoParts[1])
+        data['modelType'].append(infoParts[2])
         data['resType'].append(infoParts[3])
         data['simName'].append(fNamePart + '_' + ('_'.join(infoParts[0:3])))
 
@@ -582,3 +581,94 @@ def makeSimDF(inputDir, avaDir='', simID='simID'):
     dataDF = pd.DataFrame.from_dict(data)
 
     return dataDF
+
+
+def makeSimFromResDF(avaDir, comModule, inputDir='', simName=''):
+    """ Create a  dataFrame that contains all info on simulations in output/comModule/peakFiles
+
+        One line for each simulation - so all peakfiles that belong to one simulation are listed in one line
+        that corresponds to that simulation
+        Parameters
+        ----------
+        avaDir : str
+            path to avalanche directory
+        comModule : str
+            module used to create the results
+        inputDir : str
+            optional - path to directory of simulation results
+        simName : str
+            optional - key phrase to be found in the simulation result name
+
+        Returns
+        -------
+        dataDF : dataFrame
+            dataframe with for each simulation, the full file path, file name, release area scenario,
+            simulation type (null, entres, etc.), model type (dfa, ref, etc.), simID,
+            path to result files (ppr, pft, etc.), simulation name,
+            cell size and optional name of avalanche, optional time step
+        resTypeListAll: list
+            list of res types available for all simulations
+    """
+
+    # get path to folder containing the raster files
+    if inputDir == '':
+        inputDir = pathlib.Path(avaDir, 'Outputs', comModule, 'peakFiles')
+    if isinstance(inputDir, pathlib.Path) is False:
+        inputDir = pathlib.Path(inputDir)
+    if inputDir.is_dir() is False:
+        message = 'Input directory %s does not exist - check anaMod' % inputDir
+        log.error(message)
+        raise FileNotFoundError(message)
+
+    # Load input datasets from input directory
+    if simName != '':
+        name = '*' + simName + '*.asc'
+    else:
+        name = '*.asc'
+    datafiles = list(inputDir.glob(name))
+
+    # build the result data frame
+    dataDF = pd.DataFrame(columns=['simName'])
+    resTypeListOne = []
+    for file in datafiles:
+        name = file.stem
+        if '_AF_' in name:
+            nameParts = name.split('_AF_')
+            fNamePart = nameParts[0] + '_AF'
+            relNameSim = nameParts[0]
+            infoParts = nameParts[1].split('_')
+            resType = infoParts[-1]
+
+        else:
+            nameParts = name.split('_')
+            fNamePart = nameParts[0]
+            relNameSim = nameParts[0]
+            infoParts = nameParts[1:]
+            resType = infoParts[-1]
+        simName = fNamePart + '_' + ('_'.join(infoParts[0:-1]))
+        # add line in the DF if the simulation does not exsist yet
+        if simName not in dataDF.simName.values:
+            newLine = pd.DataFrame([[simName]], columns=['simName'], index=[simName])
+            dataDF = pd.concat([dataDF, newLine], ignore_index=False)
+            dataDF.loc[simName, 'releaseArea'] = relNameSim
+            dataDF.loc[simName, 'simType'] = infoParts[1]
+            dataDF.loc[simName, 'modelType'] = infoParts[2]
+            # add info about the cell size
+            header = IOf.readASCheader(file)
+            dataDF.loc[simName, 'cellSize'] = header['cellsize']
+        # add full path to resType
+        dataDF.loc[simName, resType] = pathlib.Path(file)
+        # list all res types found
+        if resType not in resTypeListOne:
+            resTypeListOne.append(resType)
+
+    # add a hash for each line of the DF and use as index - required for identifcation
+    hash = pd.util.hash_pandas_object(dataDF)
+    dataDF = dataDF.set_index(hash)
+    # now find res types available for all simulations
+    resTypeListAll = []
+    for resType in resTypeListOne:
+        if not dataDF[resType].isnull().values.any():
+            resTypeListAll.append(resType)
+
+    return dataDF, resTypeListAll
