@@ -3,12 +3,17 @@
 
 import logging
 import math
+import pathlib
 import numpy as np
 import scipy as sp
+import scipy.interpolate
 import copy
 
 # Local imports
+import avaframe.in3Utils.initializeProject as initProj
 import avaframe.in2Trans.ascUtils as IOf
+import avaframe.in3Utils.fileHandlerUtils as fU
+
 
 # create local logger
 log = logging.getLogger(__name__)
@@ -26,11 +31,13 @@ def projectOnRaster(dem, Points, interp='bilinear'):
         Points dictionary (x,y)
     interp: str
         interpolation option, between nearest or bilinear
+
     Returns
     -------
     Points: dict
         Points dictionary with z coordinate added or updated
-
+    ioob: int
+        number of out of bounds indexes
     """
     header = dem['header']
     rasterdata = dem['rasterData']
@@ -257,66 +264,172 @@ def remeshData(rasterFile, cellSize):
     return raster
 
 
-def remeshDEM(cfg, dem):
-    """ change DEM cell size by reprojecting on a new grid
+def remeshDEM(demFile, cfgSim):
+    """ change DEM cell size by reprojecting on a new grid - first check if remeshed DEM available
 
-    the new DEM is as big or smaller as the original DEM
+    the new DEM is as big or smaller as the original DEM and saved to Inputs/DEMremshed as remeshedDEMcellSize
 
     Interpolation is based on griddata with a cubic method. Here would be the place
     to change the order of the interpolation or to switch to another interpolation method.
 
     Parameters
     ----------
-    cfg : configParser
+    demFile: str or pathlib path
+        path to DEM in Inputs/
+    cfgSim : configParser
         meshCellSizeThreshold : threshold under which no remeshing is done
         meshCellSize : desired cell size
 
-    dem : dict
-        dem dictionary
-
     Returns
     -------
-    dem : dict
-        reprojected dem dictionary
+    pathDem : str
+        path of DEM with desired cell size relative to Inputs/
 
     """
 
-    cszThreshold = cfg.getfloat('meshCellSizeThreshold')
-    cszNew = cfg.getfloat('meshCellSize')
-    # read dem header
+    # first check if remeshed DEM is available
+    pathDem, DEMFound, allDEMNames = searchRemeshedDEM(demFile.stem, cfgSim)
+    if DEMFound:
+        return pathDem
+
+    #-------- if no remeshed DEM found - remesh
+
+    # fetch info on dem file
+    dem = IOf.readRaster(demFile)
     headerDEM = dem['header']
+
+    # fetch info on desired meshCellSize
+    meshCellSize = float(cfgSim['GENERAL']['meshCellSize'])
+    meshCellSizeThreshold = float( cfgSim['GENERAL']['meshCellSizeThreshold'])
+
+    # read dem header info
     cszDEM = headerDEM['cellsize']
-    # remesh if input DEM size does not correspond to the computational cellSize
-    if np.abs(cszNew - cszDEM) > cszThreshold:
-        log.info('Remeshing the input DEM (of cell size %.4g m) to a cell size of %.4g m' % (cszDEM, cszNew))
-        x, y, xNew, yNew, diffExtentX, diffExtentY = getMeshXY(dem, cellSizeNew=cszNew)
-        xGrid, yGrid = np.meshgrid(x, y)
-        xGrid = xGrid.flatten()
-        yGrid = yGrid.flatten()
-        z = dem['rasterData']
-        zCopy = np.copy(z)
-        zCopy = zCopy.flatten()
-        mask = np.where(~np.isnan(zCopy))
-        xGrid = xGrid[mask]
-        yGrid = yGrid[mask]
-        z = zCopy[mask]
 
-        headerRemeshed = {}
-        headerRemeshed['cellsize'] = cszNew
-        headerRemeshed['ncols'] = len(xNew)
-        headerRemeshed['nrows'] = len(yNew)
-        headerRemeshed['xllcenter'] = headerDEM['xllcenter']
-        headerRemeshed['yllcenter'] = headerDEM['yllcenter']
-        headerRemeshed['noDataValue'] = headerDEM['noDataValue']
+    # start remesh
+    log.info('Remeshing the input DEM (of cell size %.4g m) to a cell size of %.4g m' % (cszDEM, meshCellSize))
+    x, y, xNew, yNew, diffExtentX, diffExtentY = getMeshXY(dem, cellSizeNew=meshCellSize)
+    xGrid, yGrid = np.meshgrid(x, y)
+    xGrid = xGrid.flatten()
+    yGrid = yGrid.flatten()
+    z = dem['rasterData']
+    zCopy = np.copy(z)
+    zCopy = zCopy.flatten()
+    mask = np.where(~np.isnan(zCopy))
+    xGrid = xGrid[mask]
+    yGrid = yGrid[mask]
+    z = zCopy[mask]
 
-        dem['header'] = headerRemeshed
-        xNewGrid, yNewGrid = np.meshgrid(xNew, yNew)
-        zNew = sp.interpolate.griddata((xGrid, yGrid), z, (xNewGrid, yNewGrid), method='cubic',
-                                       fill_value=headerDEM['noDataValue'])
-        log.info('Remeshed data extent difference x: %f and y %f' % (diffExtentX, diffExtentY))
-        dem['rasterData'] = zNew
+    # create header of remeshed DEM
+    headerRemeshed = {}
+    headerRemeshed['cellsize'] = meshCellSize
+    headerRemeshed['ncols'] = len(xNew)
+    headerRemeshed['nrows'] = len(yNew)
+    headerRemeshed['xllcenter'] = headerDEM['xllcenter']
+    headerRemeshed['yllcenter'] = headerDEM['yllcenter']
+    headerRemeshed['noDataValue'] = headerDEM['noDataValue']
 
-    return dem
+    # write new DEM dictionary
+    remeshedDEM = {'header': headerRemeshed}
+    xNewGrid, yNewGrid = np.meshgrid(xNew, yNew)
+    zNew = sp.interpolate.griddata((xGrid, yGrid), z, (xNewGrid, yNewGrid), method='cubic',
+                                   fill_value=headerDEM['noDataValue'])
+    log.info('Remeshed data extent difference x: %f and y %f' % (diffExtentX, diffExtentY))
+    remeshedDEM['rasterData'] = zNew
+
+    # save remeshed DEM
+    pathToDem = pathlib.Path(cfgSim['GENERAL']['avalancheDir'], 'Inputs', 'DEMremeshed')
+    fU.makeADir(pathToDem)
+    outFile = pathToDem / ('%s_remeshedDEM%.2f.asc' % (demFile.stem, remeshedDEM['header']['cellsize']))
+    if outFile.name in allDEMNames:
+        message = 'Name for saving remeshedDEM already used: %s' % outFile.name
+        log.error(message)
+        raise FileExistsError(message)
+
+    IOf.writeResultToAsc(remeshedDEM['header'], remeshedDEM['rasterData'], outFile, flip=True)
+    log.info('Saved remeshed DEM to %s' % outFile)
+    pathDem = str(pathlib.Path('DEMremeshed', outFile.name))
+
+    return pathDem
+
+
+def searchRemeshedDEM(demName, cfgSim):
+    """ search if remeshed DEM with correct name and cell size already available
+
+        Parameters
+        -----------
+        demName: str
+            name of DEM file in Inputs/
+        cfgSim: configparser object
+            configuration settings: avaDir, meshCellSize, meshCellSizeThreshold
+
+        Returns
+        --------
+        remshedDEM: dict
+            dictionary of remeshed DEM if not found empty dict
+        DEMFound: bool
+            flag if dem is found
+        allDEMNames: list
+            list of all names of dems found in Inputs/DEMremeshed
+    """
+
+    # path to remeshed DEM folder
+    pathToDems = pathlib.Path(cfgSim['GENERAL']['avalancheDir'], 'Inputs', 'DEMremeshed')
+    DEMFound = False
+    pathDem = ''
+    allDEMNames = []
+
+    # fetch info on desired meshCellSize
+    meshCellSize = float(cfgSim['GENERAL']['meshCellSize'])
+    meshCellSizeThreshold = float( cfgSim['GENERAL']['meshCellSizeThreshold'])
+
+    # check if DEM is available
+    if pathToDems.is_dir():
+        # look for dems and check if cellSize within tolerance and origin matches
+        demFiles = list(pathToDems.glob('*.asc'))
+        allDEMNames = [d.name for d in demFiles]
+        for demF in demFiles:
+            headerDEM = IOf.readASCheader(demF)
+            if abs(meshCellSize - headerDEM['cellsize']) < meshCellSizeThreshold and demName in demF.stem:
+                log.info('Remeshed DEM found: %s cellSize: %.5f' % (demF.name, headerDEM['cellsize']))
+                DEMFound = True
+                pathDem = str(pathlib.Path('DEMremeshed', demF.name))
+                continue
+            else:
+                log.debug('Remeshed dem found %s with cellSize %.2f - not used' %
+                    (demF, headerDEM['cellsize']))
+
+    else:
+        log.debug('Directory %s does not exist' % pathToDems)
+
+    return pathDem, DEMFound, allDEMNames
+
+
+
+def computeS(avaPath):
+    """ compute s coordinate given a path (x, y)
+
+    Parameters
+    -----------
+    avaPath: dict
+        path dictionary with x and y coordinates as 1D numpy arrays
+
+    Returns
+    --------
+    avaPath: dict
+        path dictionary updated with s coordinate
+    """
+    xcoord = avaPath['x']
+    ycoord = avaPath['y']
+    n = np.size((xcoord))
+    # compute s
+    dxs = xcoord[1:n]-xcoord[0:n-1]
+    dys = ycoord[1:n]-ycoord[0:n-1]
+    # deduce the distance in s direction
+    ds2 = (dxs*dxs + dys*dys)
+    ds = np.sqrt(ds2)
+    scoord = np.cumsum(ds)
+    avaPath['s'] = np.insert(scoord, 0, 0)
+    return avaPath
 
 
 def prepareLine(dem, avapath, distance=10, Point=None):
@@ -339,7 +452,7 @@ def prepareLine(dem, avapath, distance=10, Point=None):
 
     Returns
     -------
-    AvaProfile: dict
+    avaProfile: dict
         the resampled avapath with the z coordinate
     projPoint: dict
         point dictionary projected on the profile (if several points
@@ -367,28 +480,63 @@ def prepareLine(dem, avapath, distance=10, Point=None):
             ycoornew = np.append(ycoornew, yn)
             s = np.append(s, S0 + D * j / nd)
 
-    ResampAvaPath = avapath
-    ResampAvaPath['x'] = xcoornew
-    ResampAvaPath['y'] = ycoornew
-    ResampAvaPath, _ = projectOnRaster(dem, ResampAvaPath)
-    ResampAvaPath['s'] = s
-    AvaProfile = ResampAvaPath
+    resampAvaPath = avapath
+    resampAvaPath['x'] = xcoornew
+    resampAvaPath['y'] = ycoornew
+    resampAvaPath, _ = projectOnRaster(dem, resampAvaPath)
+    resampAvaPath['s'] = s
+    avaProfile = resampAvaPath
     # find split point by computing the distance to the line
     if Point:
-        projPoint = findSplitPoint(AvaProfile, Point)
+        projPoint = findSplitPoint(avaProfile, Point)
     else:
         projPoint = None
 
-    return AvaProfile, projPoint
+    return avaProfile, projPoint
 
 
-def findSplitPoint(AvaProfile, Points):
-    """ Finds the closest point in Points to the AvaProfile and returns
-    its projection on AvaProfile.
+def findPointOnDEM(dem, vDirX, vDirY, vDirZ, zHighest, xFirst, yFirst, zFirst):
+    """ find point on dem given a direction and a z value to reach
 
     Parameters
     -----------
-    AvaProfile: dict
+    dem: dict
+        dem dict
+    vDirX, vDirY, vDirZ: floats
+        x, y and z components of the direction in which to extend
+    zHighest: float
+        z value to reach
+    xFirst, yFirst, zFirst: floats
+        x, y and z coordinates of the starting point
+
+    Returns
+    --------
+    xExtTop, yExtTop, zExtTop:floats
+        x, y and z coordinates of the point found
+    """
+    header = dem['header']
+    xllc = header['xllcenter']
+    yllc = header['yllcenter']
+    csz = header['cellsize']
+    zRaster = dem['rasterData']
+    gamma = (zHighest - zFirst) / vDirZ * np.linspace(0.25, 2, 100)
+    xArray = xFirst + gamma * vDirX
+    yArray = yFirst + gamma * vDirY
+    zArray, _ = projectOnGrid(xArray, yArray, zRaster, csz=csz, xllc=xllc, yllc=yllc, interp='bilinear')
+    idx = np.nanargmin(np.abs(zArray - np.array([zHighest])))
+    xExtTop = np.array([xFirst + gamma[idx] * vDirX])
+    yExtTop = np.array([yFirst + gamma[idx] * vDirY])
+    zExtTop = np.array([zArray[idx]])
+    return xExtTop, yExtTop, zExtTop
+
+
+def findSplitPoint(avaProfile, Points):
+    """ Finds the closest point in Points to the avaProfile and returns
+    its projection on avaProfile.
+
+    Parameters
+    -----------
+    avaProfile: dict
         line dictionary with x and y coordinates
     Point: dict
         a point dictionary
@@ -400,8 +548,8 @@ def findSplitPoint(AvaProfile, Points):
         were give in input, only the closest point to the profile
         is projected)
     """
-    xcoor = AvaProfile['x']
-    ycoor = AvaProfile['y']
+    xcoor = avaProfile['x']
+    ycoor = avaProfile['y']
     Dist = np.empty((0))
     IndSplit = np.empty((0))
     for i in range(len(Points['x'])):
@@ -413,54 +561,54 @@ def findSplitPoint(AvaProfile, Points):
     ind = np.argmin(Dist)
     indSplit = int(IndSplit[ind])
     projPoint = {}
-    projPoint['x'] = AvaProfile['x'][indSplit]
-    projPoint['y'] = AvaProfile['y'][indSplit]
-    projPoint['z'] = AvaProfile['z'][indSplit]
-    projPoint['s'] = AvaProfile['s'][indSplit]
+    projPoint['x'] = avaProfile['x'][indSplit]
+    projPoint['y'] = avaProfile['y'][indSplit]
+    projPoint['z'] = avaProfile['z'][indSplit]
+    projPoint['s'] = avaProfile['s'][indSplit]
     projPoint['indSplit'] = indSplit
     return projPoint
 
 
-def checkProfile(AvaProfile, projSplitPoint=None):
+def checkProfile(avaProfile, projSplitPoint=None):
     """ check that the avalanche profiles goes from top to bottom
     flip it if not and adjust the splitpoint in consequence
 
     Parameters
     -----------
-    AvaProfile: dict
+    avaProfile: dict
         line dictionary with x and y coordinates
     projSplitPoint: dict
-        a point dictionary already projected on the AvaProfile
+        a point dictionary already projected on the avaProfile
 
     Returns
     -------
-    AvaProfile: dict
-        avaprofile, fliped if needed
+    avaProfile: dict
+        avaProfile, fliped if needed
     projSplitPoint: dict
         point dictionary
     """
     if projSplitPoint:
         indSplit = projSplitPoint['indSplit']
-    if AvaProfile['z'][-1] > AvaProfile['z'][0]:
+    if avaProfile['z'][-1] > avaProfile['z'][0]:
         log.info('Profile reversed')
-        AvaProfile['x'] = np.flip(AvaProfile['x'])
-        AvaProfile['y'] = np.flip(AvaProfile['y'])
-        AvaProfile['z'] = np.flip(AvaProfile['z'])
+        avaProfile['x'] = np.flip(avaProfile['x'])
+        avaProfile['y'] = np.flip(avaProfile['y'])
+        avaProfile['z'] = np.flip(avaProfile['z'])
         try:
-            L = AvaProfile['s'][-1]
-            AvaProfile['s'] = L - np.flip(AvaProfile['s'])
+            L = avaProfile['s'][-1]
+            avaProfile['s'] = L - np.flip(avaProfile['s'])
         except KeyError:
             pass
 
         if projSplitPoint:
-            indSplit = len(AvaProfile['x']) - indSplit - 1
+            indSplit = len(avaProfile['x']) - indSplit - 1
             projSplitPoint['indSplit'] = indSplit
-            AvaProfile['indSplit'] = indSplit
+            avaProfile['indSplit'] = indSplit
         else:
             projSplitPoint = None
-            AvaProfile['indSplit'] = None
+            avaProfile['indSplit'] = None
 
-    return projSplitPoint, AvaProfile
+    return projSplitPoint, avaProfile
 
 
 def findAngleProfile(tmp, ds, dsMin):
@@ -485,11 +633,11 @@ def findAngleProfile(tmp, ds, dsMin):
     idsAnglePoint: int
         index of beta point
     """
-    noBetaFoundMessage = 'No Beta point found. Check your pathAB.shp and splitPoint.shp.'
+    noPointFoundMessage = 'No point found. Check the angle and threshold distance.'
     i = 0
     condition = True
     if np.size(tmp) == 0:
-        raise IndexError(noBetaFoundMessage)
+        raise IndexError(noPointFoundMessage)
     while (i <= np.size(tmp) and condition):
         ind = tmp[i]
         j = 0
@@ -499,7 +647,7 @@ def findAngleProfile(tmp, ds, dsMin):
                 condition = condition and (tmp[i+j+1] == ind+j+1)
                 dist = dist + ds[i + j]
             except IndexError:
-                raise IndexError(noBetaFoundMessage)
+                raise IndexError(noPointFoundMessage)
             if not condition:
                 i = i + j + 1
                 break
@@ -511,7 +659,7 @@ def findAngleProfile(tmp, ds, dsMin):
     return idsAnglePoint
 
 
-def prepareAngleProfile(beta, AvaProfile):
+def prepareAngleProfile(beta, avaProfile, raiseWarning=True):
     """Prepare inputs for findAngleProfile function
     Read profile (s, z), compute the slope Angle
     look for points for which the slope is under the given Beta value and
@@ -521,8 +669,10 @@ def prepareAngleProfile(beta, AvaProfile):
     ----------
     beta: float
         beta angle in degrees
-    AvaProfile: dict
+    avaProfile: dict
         profile dictionary, s, z and a split point(optional)
+    raiseWarning: bool
+        True to raise eventual warnings
     Returns
     -------
     angle: 1D numpy array
@@ -534,24 +684,25 @@ def prepareAngleProfile(beta, AvaProfile):
         distance between points discribed in tmp
     """
 
-    s = AvaProfile['s']
-    z = AvaProfile['z']
+    s = avaProfile['s']
+    z = avaProfile['z']
     try:
-        indSplit = AvaProfile['indSplit']
-        CuSplit = s[indSplit]
+        indSplit = avaProfile['indSplit']
+        sSplit = s[indSplit]
     except KeyError:
-        log.warning('No split Point given!')
-        CuSplit = 0
+        if raiseWarning:
+            log.warning('No split Point given!')
+        sSplit = 0
     ds = np.abs(s - np.roll(s, 1))
     dz = np.roll(z, 1) - z
-    ds[0] = 0.0
-    dz[0] = 0.0
+    ds[0] = ds[1]
+    dz[0] = dz[1]
     angle = np.rad2deg(np.arctan2(dz, ds))
-    # get all values where Angle < 10 but >0
+    # get all values where Angle < beta but >0
     # get index of first occurance and go one back to get previous value
-    # (i.e. last value above 10 deg)
-    # tmp = x[(angle < 10.0) & (angle > 0.0) & (x > 450)]
-    tmp = np.where((angle <= beta) & (s > CuSplit))
+    # (i.e. last value above beta)
+    # tmp = x[(angle < beta) & (angle > 0.0) & (x > 450)]
+    tmp = np.where((angle <= beta) & (s > sSplit))
     tmp = np.asarray(tmp).flatten()
     ds = ds[tmp]
     return angle, tmp, ds
@@ -713,3 +864,101 @@ def checkOverlap(toCheckRaster, refRaster, nameToCheck, nameRef, crop=False):
             raise AssertionError(message)
 
     return toCheckRaster
+
+
+def cartToSpherical(X, Y, Z):
+    """ convert from cartesian to spherical coordinates
+
+        Parameters
+        -----------
+        X: float
+            x coordinate
+        Y: float
+            y coordinate
+        Z: float
+            z coordinate
+
+        Returns
+        ---------
+        r: float
+            radius
+        phi: float
+            azimuth angle [degrees]
+        theta: float
+            for elevation angle defined from Z-axis down [degrees]
+    """
+
+    xy = X** 2 + Y**2
+    r = np.sqrt(xy + Z**2)
+     # for elevation angle defined from Z-axis down
+    theta = np.arctan2(np.sqrt(xy), Z)
+    theta = np.degrees(theta)
+    # azimuth: 0 degree is south
+    phi = np.arctan2(X, Y)
+    phi = np.degrees(phi)
+
+    return r, phi, theta
+
+
+def rotate(locationPoints, theta, deg=True):
+    """ rotate a vector provided as start and end point with theta angle
+        rotation counter-clockwise
+
+        Parameters
+        -----------
+        locationPoints: list
+            list of lists with x,y coordinate of start and end point of a line
+        theta: float
+            rotation angle of the vector from start point to end point - degree default
+        deg: bool
+            if true theta is converted to rad from degree
+
+        Returns
+        --------
+        rotatedLine: list
+            list of lists of x,y coordinates of start and end point of rotated vector
+    """
+
+    # convert to rad if provided as degree
+    if deg:
+        theta = np.radians(theta)
+
+    # create vector with origin 0,0
+    vector = np.diff(locationPoints)
+
+    # create rotation matrix
+    # counterclockwise rotation
+    rotationMatrix = np.array([
+        [np.cos(theta), -np.sin(theta)],
+        [np.sin(theta), np.cos(theta)],
+        ])
+
+    # rotate vector
+    vectorRot = np.dot(rotationMatrix, vector)
+
+    # create rotated line as list of start and end point
+    rotatedLine = [[locationPoints[0][0], float(locationPoints[0][0]+vectorRot[0])], # x
+           [locationPoints[1][0], float(locationPoints[1][0]+vectorRot[1])] #y
+          ]
+
+    return rotatedLine
+
+
+def makeCoordinateGrid(xllc, yllc, csz, ncols, nrows):
+    """get a Coordinate Grid for plotting"""
+
+    xEnd = (ncols-1) * csz
+    yEnd = (nrows-1) * csz
+
+    xp = np.linspace(xllc, xllc + xEnd, ncols)
+    yp = np.linspace(yllc, yllc + yEnd, nrows)
+
+    X, Y = np.meshgrid(xp, yp)
+    return(X, Y)
+
+
+def setCoordinateGrid(xllc, yllc, csz, z):
+    """get a Coordinate Grid for plotting"""
+    nrows, ncols = z.shape
+    X, Y = makeCoordinateGrid(xllc, yllc, csz, ncols, nrows)
+    return(X, Y)
