@@ -8,21 +8,24 @@ import logging
 
 # Local imports
 from avaframe.in3Utils import fileHandlerUtils as fU
+import avaframe.in3Utils.initializeProject as initProj
 
 # create local logger
 # change log level in calling module to DEBUG to see log messages
 log = logging.getLogger(__name__)
 
 
-def initialiseRunDirs(avaDir, modName):
+def initialiseRunDirs(avaDir, modName, cleanDEMremeshed):
     """ Initialise Simulation run with input data
 
         Parameters
         ----------
         avaDir : str
-            path to avalanche directoy
+            path to avalanche directory
         modName : str
             name of module
+        cleanDEMremeshed: bool
+            if True directory Inputs/DEMremeshed shall be cleaned
 
         Returns
         -------
@@ -43,4 +46,7 @@ def initialiseRunDirs(avaDir, modName):
         workDir.mkdir(parents=True, exist_ok=False)
     log.debug('Directory: %s created' % workDir)
 
+    if cleanDEMremeshed is True:
+        initProj.cleanDEMremeshedDir(avaDir)
+
     return workDir, outputDir
