@@ -38,7 +38,7 @@ def _checkAvaDirVariable(avaDir):
     return 'SUCCESS'
 
 
-def cleanModuleFiles(avaDir, module, alternativeName=''):
+def cleanModuleFiles(avaDir, module, alternativeName='', deleteOutput=True):
     '''Cleans all generated files from the provided module in the outputs
     folder and work folder
 
@@ -53,11 +53,12 @@ def cleanModuleFiles(avaDir, module, alternativeName=''):
         whereas
         from avaframe.com2AB import com2AB as c2
         leads to cleanModuleFiles(c2)
+        Boolean to be able to avoid deletion of Outputs (true by default)
     '''
 
     # check for empty or non string variable
     result = _checkAvaDirVariable(avaDir)
-    if not 'SUCCESS' in result:
+    if 'SUCCESS' not in result:
         return result
 
     # get filename of module
@@ -72,8 +73,9 @@ def cleanModuleFiles(avaDir, module, alternativeName=''):
     outDir = os.path.join(avaDir, 'Outputs')
     workDir = os.path.join(avaDir, 'Work')
 
-    log.info("Cleaning module %s in folder: %s ", modName, outDir)
-    _checkForFolderAndDelete(outDir, modName)
+    if deleteOutput:
+        log.info("Cleaning module %s in folder: %s ", modName, outDir)
+        _checkForFolderAndDelete(outDir, modName)
     _checkForFolderAndDelete(workDir, modName)
 
     return 'SUCCESS'
@@ -90,7 +92,7 @@ def cleanSingleAvaDir(avaDir, keep=None, deleteOutput=True):
 
     # check for empty or non string variable
     result = _checkAvaDirVariable(avaDir)
-    if not 'SUCCESS' in result:
+    if 'SUCCESS' not in result:
         return result
 
     # Info to user
@@ -121,6 +123,31 @@ def cleanSingleAvaDir(avaDir, keep=None, deleteOutput=True):
     return 'Cleaned directory'
 
 
+def cleanDEMremeshedDir(avaDir):
+    """ clean DEMremeshed folder in avaDir Inputs
+
+        Parameters
+        ------------
+        avaDir: str or pathlib patch
+            path to avalanche directory
+    """
+
+    avaDirInputs = pathlib.Path(avaDir, 'Inputs')
+    avaDirInputsString = str(avaDirInputs)
+
+    # check for empty or non string variable
+    result = _checkAvaDirVariable(avaDirInputsString)
+    if 'SUCCESS' not in result:
+        return result
+
+    # clean directory
+    folderName = 'DEMremeshed'
+    _checkForFolderAndDelete(avaDirInputsString, folderName)
+    log.info('Cleaned %s/%s directory' % (avaDirInputsString,folderName))
+
+    return 'SUCCESS'
+
+
 def initializeFolderStruct(pathAvaName, removeExisting=False):
     ''' Initialize the standard folder structure. If removeExisting is true,
     deletes any existing folders! BEWARE!
