@@ -177,7 +177,7 @@ def writeCompareReport(reportFile, reportD, benchD, avaName, cfgRep):
             if value != 'type':
                 pfile.write('##### Figure:   %s \n' % value)
                 pfile.write(' \n')
-                if value == 'ppr' or value == 'pfd' or value == 'pfv':
+                if value == 'ppr' or value == 'pft' or value == 'pfv':
                     maxDiff = max(abs(float(reportD['Simulation Difference'][value][2])),
                                   abs(float(reportD['Simulation Difference'][value][0])))
                     maxVal = float(reportD['Simulation Stats'][value][0])
@@ -193,7 +193,7 @@ def writeCompareReport(reportFile, reportD, benchD, avaName, cfgRep):
                         pfile.write(' %s \n' % textString1)
                         pfile.write(' %s \n' % textString2)
                         pfile.write(' \n')
-                pfile.write('![%s](%s) \n' % (value, reportD['Simulation Results'][value]))
+                pfile.write('![%s](%s) \n' % (value, reportD['Simulation Results'][value].name))
                 pfile.write(' \n')
                 pfile.write(' \n')
 
