@@ -76,53 +76,64 @@ def plotAllPeakFields(avaDir, cfgFLAGS, modName, demData=''):
         resType = peakFilesDF['resType'][m]
         log.debug('now plot %s:' % (fileName))
 
-        # Load data
-        raster = IOf.readRaster(fileName, noDataToNan=True)
-        data = raster['rasterData']
-
-        # constrain data to where there is data
-        cellSize = peakFilesDF['cellSize'][m]
-        rowsMin, rowsMax, colsMin, colsMax = pU.constrainPlotsToData(data, cellSize)
-        dataConstrained = data[rowsMin:rowsMax+1, colsMin:colsMax+1]
-        demConstrained = demField[rowsMin:rowsMax+1, colsMin:colsMax+1]
-
-        data = np.ma.masked_where(dataConstrained == 0.0, dataConstrained)
-        unit = pU.cfgPlotUtils['unit%s' % resType]
-
-        # Set extent of peak file
-        ny = data.shape[0]
-        nx = data.shape[1]
-        Ly = ny*cellSize
-        Lx = nx*cellSize
-
-        # Figure  shows the result parameter data
-        fig, ax = plt.subplots(figsize=(pU.figW, pU.figH))
-        # choose colormap
-        cmap, _, ticks, norm = pU.makeColorMap(pU.colorMaps[resType], np.amin(data), np.amax(data), continuous=pU.contCmap)
-        cmap.set_bad(alpha=0)
-        rowsMinPlot = rowsMin*cellSize
-        rowsMaxPlot = (rowsMax+1)*cellSize
-        colsMinPlot = colsMin*cellSize
-        colsMaxPlot = (colsMax+1)*cellSize
-        im0 = ax.imshow(demConstrained, cmap='Greys', extent=[colsMinPlot, colsMaxPlot, rowsMinPlot, rowsMaxPlot], origin='lower', aspect='equal')
-        im1 = ax.imshow(data, cmap=cmap, norm=norm, extent=[colsMinPlot, colsMaxPlot, rowsMinPlot, rowsMaxPlot], origin='lower', aspect='equal')
-        pU.addColorBar(im1, ax, ticks, unit)
-
-        title = str('%s' % name)
-        ax.set_title(title)
-        ax.set_xlabel('x [m]')
-        ax.set_ylabel('y [m]')
-
         plotName = outDir / ('%s.%s' % (name, pU.outputFormat))
 
-        pU.putAvaNameOnPlot(ax, avaDir)
+        # only produce a plot if it does not already exists
+        # make sure to remove the outpu folder if you want to regenerate the plot
+        # this enables to append simulations to an already existing output without regenerating all plits
+        if not plotName.is_file():
+            # Load data
+            raster = IOf.readRaster(fileName, noDataToNan=True)
+            data = raster['rasterData']
 
-        fig.savefig(plotName)
-        if cfgFLAGS.getboolean('showPlot'):
-            plt.show()
-        plotPath = pathlib.Path.cwd() / plotName
-        plotDict[peakFilesDF['simName'][m]].update({peakFilesDF['resType'][m]: plotPath})
-        plt.close(fig)
+            # constrain data to where there is data
+            cellSize = peakFilesDF['cellSize'][m]
+            rowsMin, rowsMax, colsMin, colsMax = pU.constrainPlotsToData(data, cellSize)
+            dataConstrained = data[rowsMin:rowsMax+1, colsMin:colsMax+1]
+            demConstrained = demField[rowsMin:rowsMax+1, colsMin:colsMax+1]
+
+            data = np.ma.masked_where(dataConstrained == 0.0, dataConstrained)
+            unit = pU.cfgPlotUtils['unit%s' % resType]
+
+            # Set extent of peak file
+            ny = data.shape[0]
+            nx = data.shape[1]
+            Ly = ny*cellSize
+            Lx = nx*cellSize
+
+            # Figure  shows the result parameter data
+            fig, ax = plt.subplots(figsize=(pU.figW, pU.figH))
+            # choose colormap
+            cmap, col, ticks, norm = pU.makeColorMap(pU.colorMaps[resType], np.amin(data), np.amax(data), continuous=pU.contCmap)
+            cmap.set_bad(alpha=0)
+            # uncomment this to set the under value for discrete cmap transparent
+            # cmap.set_under(alpha=0)
+            rowsMinPlot = rowsMin*cellSize
+            rowsMaxPlot = (rowsMax+1)*cellSize
+            colsMinPlot = colsMin*cellSize
+            colsMaxPlot = (colsMax+1)*cellSize
+            extent = [colsMinPlot, colsMaxPlot, rowsMinPlot, rowsMaxPlot]
+
+            # add DEM hillshade with contour lines
+            ls, CS = pU.addHillShadeContours(ax, demConstrained, cellSize, extent)
+
+            # add peak field data
+            im1 = ax.imshow(data, cmap=cmap, norm=norm, extent=extent, origin='lower', aspect='equal', zorder=4)
+            pU.addColorBar(im1, ax, ticks, unit)
+
+            # add title, labels and ava Info
+            title = str('%s' % name)
+            ax.set_title(title)
+            ax.set_xlabel('x [m]')
+            ax.set_ylabel('y [m]')
+            pU.putAvaNameOnPlot(ax, avaDir)
+
+            if cfgFLAGS.getboolean('showPlot'):
+                plt.show()
+            fig.savefig(plotName)
+            plotPath = pathlib.Path.cwd() / plotName
+            plotDict[peakFilesDF['simName'][m]].update({peakFilesDF['resType'][m]: plotPath})
+            plt.close(fig)
 
     return plotDict
 
