@@ -7,9 +7,8 @@ between two datasets of identical shape.
 import matplotlib.pyplot as plt
 import numpy as np
 import numpy.ma as ma
-import os
+import pathlib
 import logging
-import glob
 
 # Local imports
 import avaframe.in2Trans.ascUtils as IOf
@@ -23,13 +22,14 @@ from avaframe.out3Plot import statsPlots as sPlot
 log = logging.getLogger(__name__)
 
 
-def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
+def generatePlot(dataDict, avaName, outDir, cfg, plotDict, crossProfile=True):
     """ Create comparison plots of two ascii datasets
 
-        This function creates two plots, one plot with four panels with, first dataset, second dataset, the absolute difference of the two datasets
-        and the absolute difference capped to a smaller range of differences (ppr: +- 100kPa, pfd: +-1m, pfv:+- 10ms-1).
-        The difference plots also include an insert showing the histogram and the cumulative density function of the differences.
-        The second plot shows a cross- and along profile cut of the two datasets.
+        This function creates two plots, one plot with four panels with, first dataset, second dataset,
+        the absolute difference of the two datasets and the absolute difference capped to a smaller range
+        of differences (ppr: +- 100kPa, pft: +-1m, pfv:+- 10ms-1).
+        The difference plots also include an insert showing the histogram and the cumulative density function
+        of the differences. The second plot shows a cross- and along profile cut of the two datasets.
         The folder and simulation name of the datasets has to be passed to the function.
 
         Parameters
@@ -47,10 +47,10 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
                 cellSize: float
                     cell size
                 suffix: str
-                    optional information about the data type compared ('ppr', 'pfd', 'pfv')
+                    optional information about the data type compared ('ppr', 'pft', 'pfv', 'P', 'FV', 'FT', 'Vx'...)
         avaName : str
             name of avalanche
-        outDir : str
+        outDir : pathlib path
             path to dictionary where plots shall be saved to
         cfg : configParser
             cfg['FLAGS'].getboolean('showPlot')
@@ -69,9 +69,9 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
     name1 = dataDict['name1']
     name2 = dataDict['name2']
     cellSize = dataDict['cellSize']
-    if dataDict['compareType'] == 'compToRef':
+    if 'suffix' in dataDict:
         simName = dataDict['simName'] + '_' + dataDict['suffix']
-        unit = dataDict['unit']
+        unit = pU.cfgPlotUtils['unit' + dataDict['suffix']]
         cmapType = pU.colorMaps[dataDict['suffix']]
     else:
         simName = 'compare'
@@ -100,7 +100,7 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
     maxVal = max(np.nanmax(data1), np.nanmax(data2))
 
     # constrain data to where there is data
-    rowsMinPlot, rowsMaxPlot, colsMinPlot, colsMaxPlot, _ = pU.constrainPlotsToData(dataExtend, cellSize, extentOption=True)
+    rowsMinPlot, rowsMaxPlot, colsMinPlot, colsMaxPlot = pU.constrainPlotsToData(dataExtend, cellSize, extentOption=True)
 
     # Location of box
     nybox = 0.05
@@ -121,7 +121,7 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
     pU.addColorBar(im1, ax1, ticks, unit)
 
     ax1.set_aspect('auto')
-    title = str('%s' % name1)
+    title = str('%s - simulation' % name1)
     ax1.set_title(title)
     ax1.set_xlabel('x [m]')
     ax1.set_ylabel('y [m]')
@@ -138,13 +138,13 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
     ax2.set_ylim([rowsMinPlot, rowsMaxPlot])
     ax2.set_aspect('auto')
     ax2.set_xlabel('x [m]')
-    title = str('%s' % name2)
+    title = str('%s - reference' % name2)
     ax2.set_title(title)
 
     ax3 = fig.add_subplot(223)
     cmap = pU.cmapdiv
-    elev_max = np.nanmax(np.abs(dataDiff))
-    im3 = plt.imshow(dataDiff, cmap=cmap, clim=(-elev_max, elev_max),
+    elevMax = np.nanmax(np.abs(dataDiff))
+    im3 = plt.imshow(dataDiff, cmap=cmap, clim=(-elevMax, elevMax),
                      extent=[0, Lx, 0, Ly],
                      origin='lower', aspect=nx/ny)
     ax3.set_xlim([colsMinPlot, colsMaxPlot])
@@ -155,7 +155,7 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
              horizontalalignment='left', verticalalignment='bottom', transform=ax3.transAxes)
     ax3.set_aspect('auto')
     ax3.set_xlabel('x [m]')
-    ax3.set_title('Difference ref-sim')
+    ax3.set_title('Difference simulation-reference')
 
     # for difference histogramm - remove dataDiff == 0 values from array
     dataDiffPlot = dataDiff[np.isnan(dataDiff) == False]
@@ -164,26 +164,21 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
     cmap = pU.cmapdiv
 
     if 'suffix' in dataDict:
-        if dataDict['suffix'] == 'pfd':
-            elev_max = 1
-        elif dataDict['suffix'] == 'ppr':
-            elev_max = 100
-        elif dataDict['suffix'] == 'pfv':
-            elev_max = 10
-        ax4.set_title('Difference capped at max difference in %s: +-%d %s' % (dataDict['suffix'], elev_max, unit))
+        elevMax = pU.cfgPlotUtils.getfloat('elevMax' + dataDict['suffix'])
+        ax4.set_title('Difference capped at max difference in %s: +-%.2g %s' % (dataDict['suffix'], elevMax, unit))
 
     else:
         cutVal = 0.5
-        elev_max = cutVal * elev_max
-        ax4.set_title('Difference capped at %.1f times max difference: +-%.2f' % (cutVal, elev_max))
+        elevMax = cutVal * elevMax
+        ax4.set_title('Difference capped at %.1f times max difference: +-%.2f' % (cutVal, elevMax))
 
     # for difference histogramm - remove dataDiff == 0 values from array
-    dataDiffZoom = np.where((dataDiffPlot <- elev_max) | (dataDiffPlot > elev_max), np.nan, dataDiffPlot)
+    dataDiffZoom = np.where((dataDiffPlot < -elevMax) | (dataDiffPlot > elevMax), np.nan, dataDiffPlot)
     diffMaxZoom = np.nanmax(dataDiffZoom)
     diffMinZoom = np.nanmin(dataDiffZoom)
     diffMeanZoom = np.nanmean(dataDiffZoom)
 
-    im4 = plt.imshow(dataDiff, cmap=cmap, clim=(-elev_max, elev_max),
+    im4 = plt.imshow(dataDiff, cmap=cmap, clim=(-elevMax, elevMax),
                      extent=[0, Lx, 0, Ly],
                      origin='lower', aspect=nx/ny)
     ax4.set_xlim([colsMinPlot, colsMaxPlot])
@@ -206,34 +201,38 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
                  (centiles[0], unit, centiles[1], unit),
                  horizontalalignment='left', verticalalignment='bottom', transform=ax4.transAxes)
 
-    fig.savefig(os.path.join(outDir, 'Diff_%s_%s.%s' % (avaName, simName, pU.outputFormat)))
+    saveNameDiff = outDir / ('Diff_%s_%s.%s' % (avaName, simName, pU.outputFormat))
+    fig.savefig(saveNameDiff)
 
-    # Fgiure 2 cross and lonprofile
-    fig, ax = plt.subplots(ncols=2, figsize=(pU.figW*2, pU.figH))
-    suptitle = fig.suptitle(avaName, fontsize=14, color='0.5')
-    ax[0].plot(data1[:, ny_loc], 'k', label='Reference')
-    ax[0].plot(data2[:, ny_loc], 'b--', label='Simulation')
-    ax[0].set_xlabel('Location across track [nrows]')
-    ax[0].set_ylabel('Result parameter')
-    ax[0].set_title('Cross profile at x =  %d' % ny_loc)
-    ax[1].plot(data1[nx_loc, :], 'k', label='Reference')
-    ax[1].plot(data2[nx_loc, :], 'b--', label='Simulation')
-    ax[1].set_xlabel('Location along track [ncols]')
-    ax[1].set_ylabel('Result parameter')
-    ax[1].set_title('Long profile at y =  %d' % nx_loc)
-    ax[0].legend()
-    ax[1].legend()
-    fig.savefig(os.path.join(outDir, 'Profiles_%s_%s.%s' % (avaName, simName, pU.outputFormat)))
+    if crossProfile:
+        # Fgiure 2 cross and lonprofile
+        fig1, ax = plt.subplots(ncols=2, figsize=(pU.figW*2, pU.figH))
+        suptitle = fig1.suptitle(avaName, fontsize=14, color='0.5')
+        ax[0].plot(data1[:, ny_loc], 'k', label='Reference')
+        ax[0].plot(data2[:, ny_loc], 'b--', label='Simulation')
+        ax[0].set_xlabel('Location across track [nrows]')
+        ax[0].set_ylabel('Result parameter')
+        ax[0].set_title('Cross profile at x =  %d' % ny_loc)
+        ax[1].plot(data1[nx_loc, :], 'k', label='Reference')
+        ax[1].plot(data2[nx_loc, :], 'b--', label='Simulation')
+        ax[1].set_xlabel('Location along track [ncols]')
+        ax[1].set_ylabel('Result parameter')
+        ax[1].set_title('Long profile at y =  %d' % nx_loc)
+        ax[0].legend()
+        ax[1].legend()
+        saveNameProfile = outDir / ('Profiles_%s_%s.%s' % (avaName, simName, pU.outputFormat))
+        fig1.savefig(saveNameProfile)
 
     log.info('Figures saved to: %s' % outDir)
 
     if cfg['FLAGS'].getboolean('showPlot'):
         plt.show()
 
-    plotDict['plots'].append(os.path.join(outDir, 'Diff_%s_%s.%s' % (avaName, simName, pU.outputFormat)))
+    plotDict['plots'].append(saveNameDiff)
     plotDict['difference'].append(diffMax)
     plotDict['difference'].append(diffMean)
     plotDict['difference'].append(diffMin)
+    # stats is the max and min value of the reference
     plotDict['stats'].append(np.amax(data2))
     plotDict['stats'].append(np.amin(data2))
     if 'differenceZoom' in plotDict:
@@ -242,6 +241,8 @@ def generatePlot(dataDict, avaName, outDir, cfg, plotDict):
         plotDict['differenceZoom'].append(diffMinZoom)
 
     plt.close(fig)
+    if crossProfile:
+        plt.close(fig1)
 
     return plotDict
 
@@ -251,19 +252,23 @@ def quickPlotBench(avaDir, simNameRef, simNameComp, refDir, compDir, cfg, suffix
         (two raster datasets of identical dimension) and save to
         Outputs/out3Plot within avalanche directoy
 
-        figure 1: plot raster data for dataset1, dataset2 and their difference, their difference limited to specified range,
-                  including a histogram and the cumulative density function of the differences
+        figure 1: plot raster data for dataset1, dataset2 and their difference, their difference limited to
+                  specified range, including a histogram and the cumulative density function of the differences
         figure 2: plot cross and longprofiles for both datasets (ny_loc and nx_loc define location of profiles)
         -plots are saved to Outputs/out3Plot
 
         Parameters
         ----------
-        avaDir : str
+        avaDir : str or pathlib path
             path to avalanche directory
         simNameRef: str
             name of reference simulation
         simNameComp: str
             name of comparison simulation
+        refDir: str or pathlib path
+            path to reference file
+        compDir: str or pathlib path
+            path to comparison file
         cfg : dict
             global configuration settings
         suffix: str
@@ -278,7 +283,8 @@ def quickPlotBench(avaDir, simNameRef, simNameComp, refDir, compDir, cfg, suffix
     """
 
     # Create required directories
-    outDir = os.path.join(avaDir, 'Outputs', 'out3Plot')
+    avaDir = fU.checkPathlib(avaDir)
+    outDir = avaDir / 'Outputs' / 'out3Plot'
     fU.makeADir(outDir)
 
     # Initialise plotDictList
@@ -287,16 +293,18 @@ def quickPlotBench(avaDir, simNameRef, simNameComp, refDir, compDir, cfg, suffix
     # Initialise plotList
     plotDict = {'plots': [], 'difference': [], 'stats': []}
 
-    simRefFile = os.path.join(refDir, simNameRef + '_' + suffix + '.asc')
-    simCompFile = os.path.join(compDir, simNameComp + '_' + suffix + '.asc')
+    refDir = fU.checkPathlib(refDir)
+    compDir = fU.checkPathlib(compDir)
+    simRefFile = refDir / (simNameRef + '_' + suffix + '.asc')
+    simCompFile = compDir / (simNameComp + '_' + suffix + '.asc')
 
-    if os.path.isfile(simRefFile) == False or os.path.isfile(simCompFile) == False:
+    if not simRefFile.is_file() or not simCompFile.is_file():
         log.error('File for result type: %s not found' % suffix)
 
     # Load data
     raster = IOf.readRaster(simCompFile, noDataToNan=True)
     rasterRef = IOf.readRaster(simRefFile, noDataToNan=True)
-    data1, data2 = geoTrans.resizeData(raster, rasterRef)
+    dataComp, dataRef = geoTrans.resizeData(raster, rasterRef)
     log.debug('dataset1: %s' % simCompFile)
     log.debug('dataset2: %s' % simRefFile)
 
@@ -304,9 +312,9 @@ def quickPlotBench(avaDir, simNameRef, simNameComp, refDir, compDir, cfg, suffix
     unit = pU.cfgPlotUtils['unit%s' % suffix]
 
     # Get name of Avalanche
-    avaName = os.path.basename(avaDir)
+    avaName = avaDir.stem
     # Create dataDict to be passed to generatePlot
-    dataDict = {'data1': data1, 'data2': data2, 'name1': simNameComp + '_' + suffix,
+    dataDict = {'data1': dataComp, 'data2': dataRef, 'name1': simNameComp + '_' + suffix,
                 'name2': simNameRef + '_' + suffix, 'compareType': 'compToRef',
                 'simName': simNameComp, 'suffix': suffix, 'cellSize': cellSize, 'unit': unit}
     # Create Plots
@@ -322,29 +330,34 @@ def quickPlotSimple(avaDir, inputDir, cfg):
         figure 2: plot cross and longprofiles for both datasets (ny_loc and nx_loc define location of profiles)
         -plots are saved to Outputs/out3Plot
 
+        Be aware: files are being sorted after getting them from the directory! 
+        (Important for the differences)
+
         Parameters
         ----------
-        avaDir : str
+        avaDir : str or pathlib path
             path to avalanche directory
-        inputDir : str
+        inputDir : str or pathlib path
             path to directory of input data (only 2 raster files allowed)
         cfg: configParser object
             global configuration settings
 
     """
 
-    outDir = os.path.join(avaDir, 'Outputs', 'out3Plot')
+    avaDir = fU.checkPathlib(avaDir)
+    outDir = avaDir / 'Outputs' / 'out3Plot'
     fU.makeADir(outDir)
 
     # Get name of Avalanche
-    avaName = os.path.basename(avaDir)
+    avaName = avaDir.stem
 
     # Load input datasets from input directory
-    datafiles = glob.glob(inputDir+os.sep + '*.asc')
-    datafiles.extend(glob.glob(inputDir+os.sep + '*.txt'))
+    inputDir = fU.checkPathlib(inputDir)
+    datafiles = sorted(list(inputDir.glob('*.asc')))
+    datafiles.extend(list(inputDir.glob('*.txt')))
 
-    name1 = os.path.basename(datafiles[0])
-    name2 = os.path.basename(datafiles[1])
+    name1 = datafiles[0].name
+    name2 = datafiles[1].name
     log.info('input dataset #1 is %s' % name1)
     log.info('input dataset #2 is %s' % name2)
 
@@ -363,7 +376,9 @@ def quickPlotSimple(avaDir, inputDir, cfg):
     plotDict = {'plots': [], 'difference': [], 'stats': []}
 
     # Create Plots
-    plotList = generatePlot(dataDict, avaName, outDir, cfg, plotDict)
+    plotDictNew = generatePlot(dataDict, avaName, outDir, cfg, plotDict)
+
+    return plotDictNew
 
 
 def quickPlotOne(avaDir, datafile, cfg, locVal, axis, resType=''):
@@ -374,23 +389,25 @@ def quickPlotOne(avaDir, datafile, cfg, locVal, axis, resType=''):
 
         Parameters
         ----------
-        avaDir : str
+        avaDir : str or pathlib Path
             path to avalanche directory
-        datafile : str
+        datafile : str or pathlib path
             path to data file
         cfg : dict
             configuration including flags for plotting
         locVal : float
             location of cross profile
         resType : str
-            result parameter type e.g. 'pfd' - optional
+            result parameter type e.g. 'pft' - optional
 
     """
 
-    outDir = os.path.join(avaDir, 'out3Plot')
+    avaDir = fU.checkPathlib(avaDir)
+    outDir = avaDir / 'out3Plot'
     fU.makeADir(outDir)
 
-    name1 = os.path.basename(datafile)
+    datafile = fU.checkPathlib(datafile)
+    name1 = datafile.stem
     log.info('input dataset #1 is %s' % name1)
 
     # Load data
@@ -409,6 +426,8 @@ def quickPlotOne(avaDir, datafile, cfg, locVal, axis, resType=''):
     # Create Plots
     plotList = generateOnePlot(dataDict, outDir, cfg, plotDict)
 
+    return plotDict
+
 
 def generateOnePlot(dataDict, outDir, cfg, plotDict):
     """ Create plot of ascii dataset
@@ -417,9 +436,7 @@ def generateOnePlot(dataDict, outDir, cfg, plotDict):
         ----------
         dataDict : dict
             dictionary with info of the dataset to be plotted
-        avaName : str
-            name of avalanche
-        outDir : str
+        outDir : pathlib path
             path to dictionary where plots shall be saved to
         cfg : dict
             main configuration settings
@@ -493,14 +510,15 @@ def generateOnePlot(dataDict, outDir, cfg, plotDict):
     else:
         ax3.set_title('Profile at y ~ %d [%s] (%d)' % (location, unit, ny_loc))
 
-    fig.savefig(os.path.join(outDir, 'Profiles_%s.%s' % (name1, pU.outputFormat)))
+    saveNameProfile = outDir / ('Profiles_%s.%s' % (name1, pU.outputFormat))
+    fig.savefig(saveNameProfile)
 
     log.info('Figures saved to: %s' % outDir)
 
     if cfg['FLAGS'].getboolean('showPlot'):
         plt.show()
 
-    plotDict['plots'].append(os.path.join(outDir, 'Profiles_%s.%s' % (name1, pU.outputFormat)))
+    plotDict['plots'].append(saveNameProfile)
 
     plt.close(fig)
 
