@@ -66,29 +66,39 @@ def runOperational(avalancheDir=''):
     # Clean input directory(ies) of old work and output files
     # If you just created the ``avalancheDir`` this one should be clean but if you
     # already did some calculations you might want to clean it::
-    initProj.cleanSingleAvaDir(avalancheDir, keep=logName)
+    initProj.cleanSingleAvaDir(avalancheDir, keep=logName, deleteOutput=False)
 
     # ----------------
     # Run dense flow
-    _, _, _, _, plotDict, reportDictList = com1DFA.com1DFAMain(avalancheDir, cfgMain)
+    _, plotDict, reportDictList, _ = com1DFA.com1DFAMain(avalancheDir, cfgMain)
 
     # Get peakfiles to return to QGIS
     avaDir = pathlib.Path(avalancheDir)
     inputDir = avaDir / 'Outputs' / 'com1DFA' / 'peakFiles'
     peakFilesDF = fU.makeSimDF(inputDir, avaDir=avaDir)
 
-    # Run Alpha Beta
-    cfgAB = cfgUtils.getModuleConfig(com2AB)
-    resAB = com2AB.com2ABMain(cfgAB, avalancheDir)
-    abShpFile = outAB.writeABtoSHP(resAB)
+    # Check if profile and splitpoint exist, and only run if available
+    try:
+        # See if reading AB inputs throws errors
+        com2AB.readABinputs(avalancheDir)
+
+        # if not: Run Alpha Beta
+        cfgAB = cfgUtils.getModuleConfig(com2AB)
+        pathDict, dem, splitPoint, eqParams, resAB = com2AB.com2ABMain(cfgAB, avalancheDir)
+        abShpFile = outAB.writeABtoSHP(pathDict, resAB)
+
+        # Generate report info for com2AB
+        reportDictList, _, _ = outAB.writeABpostOut(pathDict, dem, splitPoint, eqParams, resAB, cfgMain, reportDictList)
+
+    except AssertionError as e:
+        log.info(e)
+        log.info('No Alpha Beta info, skipping')
+        abShpFile = None
 
     # ----------------
     # Collect results/plots/report  to a single directory
     # make simple plots (com1DFA, com2AB)
 
-    # Generate report info for com2AB
-    reportDictList, _, _ = outAB.writeABpostOut(resAB, cfgAB, reportDictList)
-
     # Set directory for report
     reportDir = avaDir / 'Outputs' / 'reports'
     fU.makeADir(reportDir)
