@@ -9,7 +9,6 @@
 import numpy as np
 import os
 from avaframe.in3Utils import fileHandlerUtils as fU
-from avaframe.in3Utils import initializeProject as initProj
 import pytest
 import shutil
 import pathlib
@@ -85,7 +84,7 @@ def test_checkIfFileExists():
     dirPath = pathlib.Path(__file__).parents[0]
     avaTestName = 'avaHockeyChannelPytest'
     testPath = dirPath / '..' / '..' / 'benchmarks' / avaTestName
-    pathData = testPath / 'Outputs' / 'com1DFAOri' / 'peakFiles' / 'release1HS_ent_dfa_67dc2dc10a_pfd.asc'
+    pathData = testPath / 'Outputs' / 'com1DFAOri' / 'peakFiles' / 'release1HS_ent_dfa_67dc2dc10a_pft.asc'
 
     # call function to be tested
     with pytest.raises(FileNotFoundError) as e:
@@ -115,7 +114,7 @@ def test_makeSimDF():
     cfg = {'varPar': 'test'}
     dataDF = fU.makeSimDF(inputDir, simID=cfg['varPar'])
 
-    assert dataDF['names'][0] == 'releaseTest1_entres_dfa_0.888_ppr'
+    assert dataDF['names'][0] == 'releaseTest1_0.888_entres_dfa_ppr'
     assert dataDF['releaseArea'][0] == 'releaseTest1'
     assert dataDF['simType'][0] == 'entres'
     assert dataDF['resType'][0] == 'ppr'
@@ -124,7 +123,7 @@ def test_makeSimDF():
 
     inputDir = os.path.join(dirPath, 'data', 'testSim1')
     dataDF = fU.makeSimDF(inputDir, simID=cfg['varPar'])
-    assert dataDF['names'][0] == 'releaseTest1_test_AF_entres_dfa_0.888_ppr'
+    assert dataDF['names'][0] == 'releaseTest1_test_AF_0.888_entres_dfa_ppr'
     assert dataDF['releaseArea'][0] == 'releaseTest1_test'
     assert dataDF['simType'][0] == 'entres'
     assert dataDF['resType'][0] == 'ppr'
@@ -132,6 +131,29 @@ def test_makeSimDF():
     assert dataDF['test'][0] == '0.888'
 
 
+def test_makeSimFromResDF():
+    """ Test if simulation dataFrame is generated correctly """
+
+    # Test function
+    dirPath = os.path.dirname(__file__)
+    inputDir = os.path.join(dirPath, 'data', 'testSim')
+    dataDF, resTypeList = fU.makeSimFromResDF(inputDir, 'comModule', inputDir=inputDir)
+    print(resTypeList)
+    print(dataDF.columns)
+    print(dataDF.index)
+    assert dataDF['simName'].iloc[0] == 'releaseTest1_0.888_entres_dfa'
+    assert dataDF['releaseArea'].iloc[0] == 'releaseTest1'
+    assert dataDF['simType'].iloc[0] == 'entres'
+    assert dataDF['cellSize'].iloc[0] == 5.0
+
+    inputDir = os.path.join(dirPath, 'data', 'testSim1')
+    dataDF, resTypeList = fU.makeSimFromResDF(inputDir, 'comModule', inputDir=inputDir)
+    assert dataDF['simName'].iloc[0] == 'releaseTest1_test_AF_0.888_entres_dfa'
+    assert dataDF['releaseArea'].iloc[0] == 'releaseTest1_test'
+    assert dataDF['simType'].iloc[0] == 'entres'
+    assert dataDF['cellSize'].iloc[0] == 5.0
+
+
 def test_exportcom1DFAOrigOutput(tmp_path):
     """ Test if export of result files works """
 
@@ -145,13 +167,18 @@ def test_exportcom1DFAOrigOutput(tmp_path):
     os.makedirs(outDir)
 
     # copy inut data from benchmarks folder to tmp_path and rename correctly
-    resType = ['ppr', 'pfd', 'pfv']
+    resType = ['ppr', 'pft', 'pfv']
     for m in resType:
         if m == 'pfv':
             avaData = os.path.join(dirPath, '..', '..', 'benchmarks', avaNameTest,
                                'release1PF_entres_dfa_1.25000_pfv.asc')
             input = os.path.join(avaDir, 'Work', 'com1DFAOrig', 'FullOutput_RelTh_1.25000',
                                 'release1PF_entres_dfa', 'raster', 'release1PF_entres_dfa_pv.asc')
+        elif m == 'pft':
+            avaData = os.path.join(dirPath, '..', '..', 'benchmarks', avaNameTest,
+                               'release1PF_entres_dfa_1.25000_pft.asc')
+            input = os.path.join(avaDir, 'Work', 'com1DFAOrig', 'FullOutput_RelTh_1.25000',
+                                'release1PF_entres_dfa', 'raster', 'release1PF_entres_dfa_pfd.asc')
         else:
             avaData = os.path.join(dirPath, '..', '..', 'benchmarks', avaNameTest,
                                 'release1PF_entres_dfa_1.25000_%s.asc' % m)
@@ -245,17 +272,17 @@ def test_splitTimeValueToArrayInterval():
 
     # call function to be tested
     cfgGen['tSteps'] = cfgValues
-    items = fU.splitTimeValueToArrayInterval(cfgGen)
+    items = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
     cfgGen['tSteps'] = cfgValues1
-    items1 = fU.splitTimeValueToArrayInterval(cfgGen)
+    items1 = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
     cfgGen['tSteps'] = cfgValues2
-    items2 = fU.splitTimeValueToArrayInterval(cfgGen)
+    items2 = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
     cfgGen['tSteps'] = cfgValues3
-    items3 = fU.splitTimeValueToArrayInterval(cfgGen)
+    items3 = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
     cfgGen['tSteps'] = cfgValues4
-    items4 = fU.splitTimeValueToArrayInterval(cfgGen)
+    items4 = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
     cfgGen['tSteps'] = cfgValues5
-    items5 = fU.splitTimeValueToArrayInterval(cfgGen)
+    items5 = fU.splitTimeValueToArrayInterval(cfgGen['tSteps'], cfgGen.getfloat('tEnd'))
 
     assert len(items) == len(cfgValuesList)
     assert items[0] == cfgValuesList[0]
@@ -298,43 +325,29 @@ def test_getFilterDict():
     assert parametersDict == {}
 
 
-def test_getDFADataPaths():
-    """ test generating pathDict for aimec """
+def test_fetchFlowFields():
+    """ test fetching fields in a folder """
 
-    # define input directory
-    dirPath = os.path.dirname(__file__)
-    avaName = 'avaHockeyChannel'
-    avaNameTest = 'avaHockeyChannelPytest'
-    avaDir = os.path.join(dirPath, '..', '..', 'benchmarks', avaNameTest)
-
-    cfg = configparser.ConfigParser()
-    cfg['AIMECSETUP'] = {'varParList': 'releaseScenario', 'ascendingOrder': True}
-    cfgSetup = cfg['AIMECSETUP']
-    suffix = ['ppr', 'pfd', 'pfv']
-    comModule = 'com1DFA'
-    pathDict = {'ppr': [], 'pfd': [], 'pfv': [], 'massBal': [], 'colorParameter': []}
-
-    # return pathDict for comModule=com1DFA
-    pathDict = fU.getDFADataPaths(avaDir, pathDict, cfgSetup, suffix, comModule=comModule, inputDir='')
-
-    # return pathDict for given inputDir
-    pathDict2 = {'ppr': [], 'pfd': [], 'pfv': [], 'massBal': [], 'colorParameter': []}
-    inputDir = pathlib.Path(avaDir, 'Outputs' , 'com1DFA', 'peakFiles')
+    # setup required input
+    # get input data
+    dirPath = pathlib.Path(__file__).parents[0]
+    avaName = 'avaHockeyChannelPytest'
+    flowFieldsDir = dirPath / '..' / '..' / 'benchmarks' / avaName / 'Outputs' / 'com1DFA' / 'peakFiles'
     suffix = 'ppr'
-    pathDict2 = fU.getDFADataPaths(avaDir, pathDict2, cfgSetup, suffix, comModule='', inputDir=inputDir)
-
-    # define paths
-    path1 = 'benchmarks/avaHockeyChannelPytest/Outputs/com1DFA/peakFiles/release1HS_ent_dfa_67dc2dc10a_ppr.asc'
-    path2 = 'benchmarks/avaHockeyChannelPytest/Outputs/com1DFA/peakFiles/release2HS_ent_dfa_872f0101a4_ppr.asc'
-
-    assert pathDict['colorParameter'] == ['release1HS', 'release2HS']
-    assert path1 in str(pathDict['ppr'][0])
-    assert path2 in str(pathDict['ppr'][1])
-    assert pathDict2['colorParameter'] == []
-    assert path1 in str(pathDict2['ppr'][0])
-    assert path2 in str(pathDict2['ppr'][1])
 
     # call function to be tested
-    with pytest.raises(FileNotFoundError) as e:
-        assert fU.getDFADataPaths(avaDir, pathDict2, cfgSetup, suffix, comModule='test', inputDir='')
-    assert 'Input directory' in str(e.value)
+    flowFields = fU.fetchFlowFields(flowFieldsDir, suffix=suffix)
+    flowFields = sorted(flowFields)
+    print('flowFields', flowFields, sorted(flowFields))
+
+    assert flowFields[0].stem == 'release1HS_d10bdc1e81_ent_dfa_ppr'
+    assert flowFields[1].stem == 'release2HS_e2145362b7_ent_dfa_ppr'
+    assert len(flowFields) == 2
+
+    # call function to be tested
+    flowFields = fU.fetchFlowFields(flowFieldsDir)
+    flowFields = sorted(flowFields)
+    print('flowFields', flowFields, sorted(flowFields))
+
+    assert flowFields[0].stem == 'release1HS_d10bdc1e81_ent_dfa_pft'
+    assert len(flowFields) == 6
