@@ -4,12 +4,15 @@ import math
 import pytest
 import logging
 import matplotlib.path as mpltPath
+import pathlib
+import shutil
 import os
 import configparser
 
 # Local imports
 import avaframe.in3Utils.geoTrans as geoTrans
 import avaframe.in2Trans.ascUtils as IOf
+import avaframe.in3Utils.fileHandlerUtils as fU
 
 
 log = logging.getLogger(__name__)
@@ -143,7 +146,7 @@ def test_findAngleProfile(capfd):
     # do we react properly when the input line exceeds the dem?
     with pytest.raises(Exception) as e:
         assert geoTrans.findAngleProfile(tmp, ds, dsMin)
-    assert str(e.value) == "No Beta point found. Check your pathAB.shp and splitPoint.shp."
+    assert str(e.value) == "No point found. Check the angle and threshold distance."
 
     tmp = np.where((angle < 4.0) & (angle >= 0.0))
     tmp = np.asarray(tmp).flatten()
@@ -153,7 +156,7 @@ def test_findAngleProfile(capfd):
     # do we react properly when the input line exceeds the dem?
     with pytest.raises(Exception) as e:
         assert geoTrans.findAngleProfile(tmp, ds, dsMin)
-    assert str(e.value) == "No Beta point found. Check your pathAB.shp and splitPoint.shp."
+    assert str(e.value) == "No point found. Check the angle and threshold distance."
 
 
 def test_prepareAngleProfile(caplog):
@@ -317,14 +320,20 @@ def test_remeshDEM(tmp_path):
     z0 = 10
     data = getIPZ(z0, 15, 20, 5)
 
-    dataDict = {}
-    dataDict['rasterData'] = data
-    dataDict['header'] = headerInfo
+    avaDir = pathlib.Path(tmp_path, 'avaTest')
+    fU.makeADir(avaDir)
+    fU.makeADir((avaDir / 'Inputs'))
+    avaDEM = avaDir / 'Inputs' / 'avaAlr.asc'
+    IOf.writeResultToAsc(headerInfo, data, avaDEM, flip=True)
+
     cfg = configparser.ConfigParser()
-    cfg['GENERAL'] = {'meshCellSizeThreshold': '0.0001', 'meshCellSize': '2.'}
+    cfg['GENERAL'] = {'meshCellSizeThreshold': '0.0001', 'meshCellSize': '2.', 'avalancheDir': str(avaDir)}
 
     # call function
-    dataNew = geoTrans.remeshDEM(cfg['GENERAL'], dataDict)
+    pathDem = geoTrans.remeshDEM(avaDEM, cfg)
+    fullP = avaDir / 'Inputs'/ pathDem
+    dataNew = IOf.readRaster(fullP)
+
     dataRaster = dataNew['rasterData']
     indNoData = np.where(dataRaster == -9999)
     headerNew = dataNew['header']
@@ -332,7 +341,8 @@ def test_remeshDEM(tmp_path):
     yExtent = (headerNew['nrows']-1) * headerNew['cellsize']
 
     # compute solution
-    dataSol = getIPZ(z0, xExtent, yExtent, headerNew['cellsize'])
+    dataSol = getIPZ(z0, xExtent, yExtent, 2.)
+    # dataSol = getIPZ(z0, xExtent, yExtent, headerNew['cellsize'])
 
     # compare solution to result from function
     testRes = np.allclose(dataRaster, dataSol, atol=1.e-6)
@@ -343,6 +353,44 @@ def test_remeshDEM(tmp_path):
     assert testRes
     assert np.isclose(dataRaster[0,0], 10.)
 
+    # copy data
+    avaName = 'avaParabola'
+    dirPath = pathlib.Path(__file__).parents[0]
+    inputDir1 = dirPath / '..' / 'data' / avaName
+    inputDEM = dirPath / 'data' / 'remeshedDEM8.00.asc'
+    avaDir1 = pathlib.Path(tmp_path, avaName)
+    avaDEM = avaDir1 / 'Inputs' / 'DEMremeshed' / 'DEM_PF_Topo_remeshedDEM8.00.asc'
+    shutil.copytree(inputDir1, avaDir1)
+    inputsAVA = avaDir1 / 'Inputs' / 'DEMremeshed'
+    fU.makeADir(inputsAVA)
+    shutil.copy(inputDEM, avaDEM)
+    inputDEM1 = inputDir1 / 'Inputs' / 'DEM_PF_Topo.asc'
+    avaDEM1 = avaDir1 / 'Inputs' / 'DEM_PF_Topo.asc'
+    shutil.copy(inputDEM1, avaDEM1)
+    cfg['GENERAL']['avalancheDir'] = str(avaDir1)
+    cfg['GENERAL']['meshCellSize'] = '8.'
+
+    # call function
+    pathDem2 = geoTrans.remeshDEM(avaDEM1, cfg)
+    fullP2 = avaDir1 / 'Inputs'  / pathDem2
+    dataNew2 = IOf.readRaster(fullP2)
+    dataRaster2 = dataNew2['rasterData']
+    dataSol = IOf.readRaster(inputDEM)
+    # compare solution to result from function
+    testRes2 = np.allclose(dataRaster2, dataSol['rasterData'], atol=1.e-6)
+
+    assert dataNew2['rasterData'].shape[0] == dataSol['header']['nrows']
+    assert dataNew2['rasterData'].shape[1] == dataSol['header']['ncols']
+    assert testRes2
+
+    dataMod = IOf.readRaster(inputDEM)
+    dataMod['header']['cellsize'] = 9.0
+    IOf.writeResultToAsc(dataMod['header'], dataMod['rasterData'], avaDEM, flip=True)
+
+    with pytest.raises(FileExistsError) as e:
+        assert geoTrans.remeshDEM(avaDEM1, cfg)
+    assert str(e.value) == ("Name for saving remeshedDEM already used: %s" % avaDEM.name)
+
 
 def test_isCounterClockWise(capfd):
     """ test isCounterClockWise """
@@ -396,6 +444,45 @@ def test_checkOverlap(capfd):
     assert np.allclose(checkedRaster2, toCheckRaster, atol=atol)
 
 
+def test_computeS(capfd):
+    avaPath = {}
+    avaPath['x'] = np.array([1, 4, 0, 3])
+    avaPath['y'] = np.array([0, 4, 1, -3])
+    avaPath = geoTrans.computeS(avaPath)
+    print(avaPath)
+    atol = 1e-10
+    assert len(avaPath['s']) == 4
+    assert np.allclose(avaPath['s'], np.array([0, 5, 10, 15]), atol=atol)
+
+
+def test_makeCoordinateGrid(capfd):
+    xllc = 1
+    yllc = -1
+    csz = 2
+    ncols = 3
+    nrows = 4
+    x, y = geoTrans.makeCoordinateGrid(xllc, yllc, csz, ncols, nrows)
+    print(x)
+    print(y)
+
+    assert x[0, 0] == 1
+    assert x[0, 1] == 3
+    assert x[0, 2] == 5
+    assert y[0, 1] == -1
+    assert y[1, 1] == 1
+    assert y[3, 1] == 5
+
+    x, y = geoTrans.setCoordinateGrid(xllc, yllc, csz, x)
+    print(x)
+    print(y)
+
+    assert x[0, 0] == 1
+    assert x[0, 1] == 3
+    assert x[0, 2] == 5
+    assert y[0, 1] == -1
+    assert y[1, 1] == 1
+    assert y[3, 1] == 5
+
 def getIPZ(z0, xEnd, yEnd, dx):
 
     meanAlpha = 30.
@@ -411,3 +498,81 @@ def getIPZ(z0, xEnd, yEnd, dx):
     zv = z0 - np.tan(np.radians(meanAlpha)) * x
 
     return zv
+
+
+def test_cartToSpherical():
+    """ test converting to spherical coordinates """
+
+    # setup required inputs
+    X = 10.
+    Y = 10.
+    Z = np.sqrt(10.**2 + 10.**2)
+
+    # call function to be tested
+    r, phi, theta = geoTrans.cartToSpherical(X, Y, Z)
+
+    assert r == np.sqrt(10.**2 + 10.**2 + Z**2)
+    assert phi == 45.
+    assert theta == 45.
+
+
+    # setup required inputs
+    X = np.sqrt(10.)
+    Y = 3*np.sqrt(10.)
+    Z = 20
+
+    # call function to be tested
+    r, phi, theta = geoTrans.cartToSpherical(X, Y, Z)
+
+    print('r', r, 'phi', phi, 'theta', theta)
+
+    assert r == np.sqrt(X**2 + Y**2 + Z**2)
+    assert phi == np.rad2deg(np.arctan(2)) - 45
+    assert theta == 90. - np.rad2deg(np.arctan(2))
+
+
+def test_rotate():
+    """ test rotate a vector by an angle """
+
+    # setup required data
+    locationPoints = [[0., 0.], [0., 10.]]
+    theta = 45.
+    deg = True
+
+    # call function to be tested
+    rotatedLine = geoTrans.rotate(locationPoints, theta, deg=deg)
+
+    sL = np.sqrt(50.)
+    assert rotatedLine[0][0] == 0.
+    assert -sL - 1.e-12 < rotatedLine[0][1] < -sL+1.e-12
+    assert rotatedLine[1][0] == 0.
+    assert sL - 1.e-12 < rotatedLine[1][1] < sL+1.e-12
+    assert isinstance(rotatedLine, list)
+    assert len(rotatedLine) == 2
+    assert len(rotatedLine[0]) == 2
+
+    locationPoints = [[0., 0.], [0., 10.]]
+    theta = np.rad2deg(np.arctan(2)) - 45
+    deg = True
+
+    # call function to be tested
+    rotatedLine = geoTrans.rotate(locationPoints, theta, deg=deg)
+    print('rotated line', rotatedLine)
+
+    sLX = np.sqrt(10.)
+    assert rotatedLine[0][0] == 0.
+    assert -sLX - 1.e-12 < rotatedLine[0][1] < -sLX+1.e-12
+    assert rotatedLine[1][0] == 0.
+    assert 3*sLX - 1.e-12 < rotatedLine[1][1] < 3*sLX+1.e-12
+    assert isinstance(rotatedLine, list)
+    assert len(rotatedLine) == 2
+    assert len(rotatedLine[0]) == 2
+
+    vector = np.diff(locationPoints)
+    vectorRot = np.diff(rotatedLine)
+
+    # check if rotation worked correctly
+    lenVector = np.sqrt(vector[0]**2 + vector[1]**2)
+    lenVectorRot = np.sqrt(vectorRot[0]**2 + vectorRot[1]**2)
+
+    assert np.isclose(lenVector, lenVectorRot)
